"use strict";

var EXPORTED_SYMBOLS = ["isTabPrivate", "isPrivateTabOpen", "iterTabs", "getgBrowser", "getBaseDomainFromHost", "iter", "items"];

const Cu = Components.utils;

try{
	Cu.import("resource://gre/modules/Console.jsm"); 
}
catch(error){
	Cu.import("resource://gre/modules/"+"devtools"+"/Console.jsm");
}

Cu.import("resource://gre/modules/Services.jsm");

Cu.import("resource://gre/modules/PrivateBrowsingUtils.jsm");

function getWindowForTab(tab){
    //get window for tab
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
        .getService(Components.interfaces.nsIWindowMediator);
    var browserEnumerator = wm.getEnumerator("navigator:browser");

    // Check each browser instance for our URL
    while (browserEnumerator.hasMoreElements()) {
        var browserWin = browserEnumerator.getNext();
        var tabbrowser = browserWin.gBrowser;

        // Check each tab of this browser instance
        var numTabs = tabbrowser.browsers.length;
        for (var index = 0; index < numTabs; index++) {
            var currentBrowser = tabbrowser.getBrowserAtIndex(index);
            if (currentBrowser === tab) {
                return browserWin;
                break;
            }
        }
    }
}

function isTabPrivate(tab) {
    try {
        var tabWindow = getWindowForTab(tab);
        return PrivateBrowsingUtils.isWindowPrivate(tabWindow);
    } catch (e) {
        // As per issue #73, for some unknown reason,
        // PBU.isWindowPrivate() can throw NS_NOINTERFACE.  I have never
        // been able to reproduce this on Linux, so perhaps this is
        // platform specific.  In any case, just blindly catch exceptions
        // thrown here and assume the window isn"t private if it throws.
        return false;
    }
}

function isPrivateTabOpen() {
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
        .getService(Components.interfaces.nsIWindowMediator);
    var browserEnumerator = wm.getEnumerator("navigator:browser");

    while (browserEnumerator.hasMoreElements()) {
        var browserWin = browserEnumerator.getNext();
        if (PrivateBrowsingUtils.isWindowPrivate(browserWin)) {
            return true;
        }
    }

    return false;
}

//return browser instance
function getgBrowser() {
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
        .getService(Components.interfaces.nsIWindowMediator);
    var mainWindow = wm.getMostRecentWindow("navigator:browser");
    return mainWindow ? mainWindow.gBrowser : null;
}

//call callback function for each tab (private also)
function iterTabs(callback) {
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
        .getService(Components.interfaces.nsIWindowMediator);
    var browserEnumerator = wm.getEnumerator("navigator:browser");

    // Check each browser instance for our URL
    while (browserEnumerator.hasMoreElements()) {
        var browserWin = browserEnumerator.getNext();
        var tabbrowser = browserWin.gBrowser;

        // Check each tab of this browser instance
        var numTabs = tabbrowser.browsers.length;
        for (var index = 0; index < numTabs; index++) {
            var currentBrowser = tabbrowser.getBrowserAtIndex(index);
            callback(currentBrowser);
        }
    }
}

var TLDs = {
    "0.bg": true,
    "0fees.net": true,
    "1.bg": true,
    "110mb.com": true,
    "150m.com": true,
    "163.to": true,
    "1blu.de": true,
    "2.bg": true,
    "2000.hu": true,
    "3.bg": true,
    "4.bg": true,
    "5.bg": true,
    "5ballov.ru": true,
    "6.bg": true,
    "6a.org": true,
    "6bone.pl": true,
    "7.bg": true,
    "8.bg": true,
    "9.bg": true,
    "9k.com": true,
    "a.bg": true,
    "a.se": true,
    "aa.no": true,
    "aarborte.no": true,
    "ab.ca": true,
    "ab.se": true,
    "abo.pa": true,
    "ac.ae": true,
    "ac.am": true,
    "ac.at": true,
    "ac.bd": true,
    "ac.be": true,
    "ac.ci": true,
    "ac.cn": true,
    "ac.com": true,
    "ac.cr": true,
    "ac.cy": true,
    "ac.fj": true,
    "ac.fk": true,
    "ac.gg": true,
    "ac.gn": true,
    "ac.hu": true,
    "ac.id": true,
    "ac.il": true,
    "ac.im": true,
    "ac.in": true,
    "ac.ir": true,
    "ac.je": true,
    "ac.jp": true,
    "ac.ke": true,
    "ac.kr": true,
    "ac.lk": true,
    "ac.ma": true,
    "ac.me": true,
    "ac.mu": true,
    "ac.mw": true,
    "ac.ng": true,
    "ac.nz": true,
    "ac.om": true,
    "ac.pa": true,
    "ac.pg": true,
    "ac.pr": true,
    "ac.rs": true,
    "ac.ru": true,
    "ac.rw": true,
    "ac.se": true,
    "ac.sz": true,
    "ac.th": true,
    "ac.tj": true,
    "ac.tz": true,
    "ac.ug": true,
    "ac.uk": true,
    "ac.vn": true,
    "ac.yu": true,
    "ac.za": true,
    "ac.zm": true,
    "ac.zw": true,
    "aca.pro": true,
    "academy.museum": true,
    "accident-investigation.aero": true,
    "accident-prevention.aero": true,
    "act.au": true,
    "ad.jp": true,
    "addr.com": true,
    "adm.br": true,
    "adult.ht": true,
    "adv.br": true,
    "adygeya.ru": true,
    "ae.org": true,
    "aejrie.no": true,
    "aero.mv": true,
    "aero.tt": true,
    "aerobatic.aero": true,
    "aeroclub.aero": true,
    "aerodrome.aero": true,
    "aeroport.fr": true,
    "afjord.no": true,
    "ag.it": true,
    "agdenes.no": true,
    "agents.aero": true,
    "agr.br": true,
    "agrar.hu": true,
    "agriculture.museum": true,
    "agrigento.it": true,
    "agrinet.tn": true,
    "agro.pl": true,
    "ah.cn": true,
    "ah.no": true,
    "aichi.jp": true,
    "aid.pl": true,
    "aip.ee": true,
    "air-surveillance.aero": true,
    "air-traffic-control.aero": true,
    "air.museum": true,
    "aircraft.aero": true,
    "airguard.museum": true,
    "airline.aero": true,
    "airport.aero": true,
    "airtraffic.aero": true,
    "ak.us": true,
    "akita.jp": true,
    "aknoluokta.no": true,
    "akrehamn.no": true,
    "al.it": true,
    "al.no": true,
    "al.us": true,
    "alabama.museum": true,
    "alaheadju.no": true,
    "aland.fi": true,
    "alaska.museum": true,
    "alderney.gg": true,
    "alessandria.it": true,
    "alesund.no": true,
    "algard.no": true,
    "alstahaug.no": true,
    "alt.na": true,
    "alt.za": true,
    "alta.no": true,
    "altai.ru": true,
    "altervista.org": true,
    "alto-adige.it": true,
    "altoadige.it": true,
    "alvdal.no": true,
    "am.br": true,
    "amber.museum": true,
    "ambulance.aero": true,
    "ambulance.museum": true,
    "american.museum": true,
    "americana.museum": true,
    "americanantiques.museum": true,
    "americanart.museum": true,
    "amli.no": true,
    "amot.no": true,
    "amsterdam.museum": true,
    "amur.ru": true,
    "amursk.ru": true,
    "amusement.aero": true,
    "an.it": true,
    "ancona.it": true,
    "and.museum": true,
    "andasuolo.no": true,
    "andebu.no": true,
    "andoy.no": true,
    "angelfire.com": true,
    "annefrank.museum": true,
    "anthro.museum": true,
    "anthropology.museum": true,
    "antiques.museum": true,
    "ao.it": true,
    "aomori.jp": true,
    "aosta.it": true,
    "aoste.it": true,
    "ap.it": true,
    "appspot.com": true,
    "aq.it": true,
    "aquarium.museum": true,
    "aquila.it": true,
    "ar.com": true,
    "ar.it": true,
    "ar.us": true,
    "arboretum.museum": true,
    "archaeological.museum": true,
    "archaeology.museum": true,
    "architecture.museum": true,
    "ardal.no": true,
    "aremark.no": true,
    "arendal.no": true,
    "arezzo.it": true,
    "arkhangelsk.ru": true,
    "army.mil": true,
    "arna.no": true,
    "arq.br": true,
    "art.br": true,
    "art.do": true,
    "art.dz": true,
    "art.ht": true,
    "art.museum": true,
    "art.pl": true,
    "artanddesign.museum": true,
    "artcenter.museum": true,
    "artdeco.museum": true,
    "arteducation.museum": true,
    "artgallery.museum": true,
    "arts.co": true,
    "arts.museum": true,
    "arts.nf": true,
    "arts.ro": true,
    "arts.ve": true,
    "artsandcrafts.museum": true,
    "as.us": true,
    "ascoli-piceno.it": true,
    "ascolipiceno.it": true,
    "aseral.no": true,
    "asker.no": true,
    "askim.no": true,
    "askoy.no": true,
    "askvoll.no": true,
    "asmatart.museum": true,
    "asn.au": true,
    "asn.lv": true,
    "asnes.no": true,
    "ass.dz": true,
    "ass.km": true,
    "assassination.museum": true,
    "assedic.fr": true,
    "assisi.museum": true,
    "assn.lk": true,
    "asso.ci": true,
    "asso.dz": true,
    "asso.fr": true,
    "asso.gp": true,
    "asso.ht": true,
    "asso.km": true,
    "asso.ma": true,
    "asso.mc": true,
    "asso.re": true,
    "asso.st": true,
    "asso.ws": true,
    "association.aero": true,
    "association.museum": true,
    "asti.it": true,
    "astrakhan.ru": true,
    "astronomy.museum": true,
    "at.it": true,
    "at.lv": true,
    "at.pn": true,
    "at.tc": true,
    "at.tf": true,
    "at.tt": true,
    "ath.cx": true,
    "atlanta.museum": true,
    "atm.pl": true,
    "ato.br": true,
    "au.com": true,
    "au.ms": true,
    "au.pn": true,
    "au.tc": true,
    "au.tt": true,
    "audnedaln.no": true,
    "augustow.pl": true,
    "aukra.no": true,
    "aure.no": true,
    "aurland.no": true,
    "aurskog-holand.no": true,
    "austevoll.no": true,
    "austin.museum": true,
    "australia.museum": true,
    "austrheim.no": true,
    "author.aero": true,
    "auto.pl": true,
    "automotive.museum": true,
    "av.it": true,
    "av.tr": true,
    "avellino.it": true,
    "averoy.no": true,
    "aviation.museum": true,
    "avocat.fr": true,
    "avoues.fr": true,
    "axis.museum": true,
    "az.us": true,
    "b.bg": true,
    "b.se": true,
    "ba.it": true,
    "babia-gora.pl": true,
    "badaddja.no": true,
    "badajoz.museum": true,
    "baghdad.museum": true,
    "bahcavuotna.no": true,
    "bahccavuotna.no": true,
    "bahn.museum": true,
    "baidar.no": true,
    "baikal.ru": true,
    "bajddar.no": true,
    "balat.no": true,
    "bale.museum": true,
    "balestrand.no": true,
    "ballangen.no": true,
    "ballooning.aero": true,
    "balsan.it": true,
    "balsfjord.no": true,
    "baltimore.museum": true,
    "bamble.no": true,
    "bar.pro": true,
    "barcelona.museum": true,
    "bardu.no": true,
    "bari.it": true,
    "barletta-andria-trani.it": true,
    "barlettaandriatrani.it": true,
    "barreau.fr": true,
    "barum.no": true,
    "baseball.museum": true,
    "basel.museum": true,
    "bashkiria.ru": true,
    "baths.museum": true,
    "batsfjord.no": true,
    "bauern.museum": true,
    "bbs.tr": true,
    "bc.ca": true,
    "bd.se": true,
    "be.tc": true,
    "be.tt": true,
    "bearalvahki.no": true,
    "beardu.no": true,
    "beauxarts.museum": true,
    "bedzin.pl": true,
    "bee.pl": true,
    "beeldengeluid.museum": true,
    "beiarn.no": true,
    "bel.tr": true,
    "belau.pw": true,
    "belgie.be": true,
    "belgorod.ru": true,
    "bellevue.museum": true,
    "belluno.it": true,
    "benevento.it": true,
    "berg.no": true,
    "bergamo.it": true,
    "bergbau.museum": true,
    "bergen.no": true,
    "berkeley.museum": true,
    "berlevag.no": true,
    "berlin.museum": true,
    "bern.museum": true,
    "beskidy.pl": true,
    "bg.it": true,
    "bg.tc": true,
    "bg.tf": true,
    "bi.it": true,
    "bialowieza.pl": true,
    "bialystok.pl": true,
    "bib.ve": true,
    "bible.museum": true,
    "bielawa.pl": true,
    "biella.it": true,
    "bieszczady.pl": true,
    "bievat.no": true,
    "bij.pl": true,
    "bilbao.museum": true,
    "bill.museum": true,
    "bindal.no": true,
    "bio.br": true,
    "bir.ru": true,
    "birdart.museum": true,
    "birkenes.no": true,
    "birthplace.museum": true,
    "biz.az": true,
    "biz.bh": true,
    "biz.cy": true,
    "biz.et": true,
    "biz.fj": true,
    "biz.ki": true,
    "biz.ly": true,
    "biz.mv": true,
    "biz.mw": true,
    "biz.nf": true,
    "biz.nr": true,
    "biz.om": true,
    "biz.pk": true,
    "biz.pl": true,
    "biz.pr": true,
    "biz.st": true,
    "biz.tj": true,
    "biz.tm": true,
    "biz.tr": true,
    "biz.tt": true,
    "biz.ua": true,
    "biz.vn": true,
    "bj.cn": true,
    "bjarkoy.no": true,
    "bjerkreim.no": true,
    "bjugn.no": true,
    "bl.it": true,
    "bl.uk": true,
    "blog.br": true,
    "blog.cat": true,
    "blog.com": true,
    "blog.ru": true,
    "blog4ever.com": true,
    "blogger.ca": true,
    "blogger.cf": true,
    "blogger.ch": true,
    "blogger.cv": true,
    "blogger.jp": true,
    "blogger.pl": true,
    "blogger.re": true,
    "blogger.se": true,
    "blogspot.ca": true,
    "blogspot.com": true,
    "blogspot.cv": true,
    "blogspot.de": true,
    "blogspot.fr": true,
    "blogspot.in": true,
    "blogspot.it": true,
    "blogspot.jp": true,
    "blogspot.mx": true,
    "blogspot.pt": true,
    "blogspot.re": true,
    "blogspot.se": true,
    "bmd.br": true,
    "bn.it": true,
    "bo.it": true,
    "bodo.no": true,
    "bokn.no": true,
    "boleslawiec.pl": true,
    "bologna.it": true,
    "bolt.hu": true,
    "bolzano.it": true,
    "bomlo.no": true,
    "bonn.museum": true,
    "boston.museum": true,
    "botanical.museum": true,
    "botanicalgarden.museum": true,
    "botanicgarden.museum": true,
    "botany.museum": true,
    "bourse.za": true,
    "bozen.it": true,
    "br.com": true,
    "br.it": true,
    "br.ms": true,
    "br.tc": true,
    "brand.se": true,
    "brandywinevalley.museum": true,
    "brasil.museum": true,
    "bravehost.com": true,
    "bravepages.com": true,
    "bremanger.no": true,
    "brescia.it": true,
    "brindisi.it": true,
    "bristol.museum": true,
    "british-library.uk": true,
    "british.museum": true,
    "britishcolumbia.museum": true,
    "broadcast.museum": true,
    "broker.aero": true,
    "bronnoy.no": true,
    "bronnoysund.no": true,
    "brumunddal.no": true,
    "brunel.museum": true,
    "brussel.museum": true,
    "brussels.museum": true,
    "bruxelles.museum": true,
    "bryansk.ru": true,
    "bryne.no": true,
    "bs.it": true,
    "bu.no": true,
    "budejju.no": true,
    "building.museum": true,
    "burghof.museum": true,
    "buryatia.ru": true,
    "bus.museum": true,
    "busan.kr": true,
    "bushey.museum": true,
    "by.ru": true,
    "bydgoszcz.pl": true,
    "bygland.no": true,
    "bykle.no": true,
    "bytom.pl": true,
    "bz.cm": true,
    "bz.it": true,
    "c.bg": true,
    "c.la": true,
    "c.se": true,
    "ca.it": true,
    "ca.na": true,
    "ca.pn": true,
    "ca.tf": true,
    "ca.tt": true,
    "ca.us": true,
    "caa.aero": true,
    "cadaques.museum": true,
    "cagliari.it": true,
    "cahcesuolo.no": true,
    "california.museum": true,
    "caltanissetta.it": true,
    "cambridge.museum": true,
    "campobasso.it": true,
    "can.br": true,
    "can.museum": true,
    "canada.museum": true,
    "capebreton.museum": true,
    "cargo.aero": true,
    "carrier.museum": true,
    "cartoonart.museum": true,
    "casadelamoneda.museum": true,
    "caserta.it": true,
    "casino.hu": true,
    "castle.museum": true,
    "castres.museum": true,
    "catania.it": true,
    "catanzaro.it": true,
    "catering.aero": true,
    "cb.it": true,
    "cbg.ru": true,
    "cc.bh": true,
    "cc.cc": true,
    "cc.na": true,
    "cci.fr": true,
    "ce.it": true,
    "ce.ms": true,
    "celtic.museum": true,
    "center.museum": true,
    "certification.aero": true,
    "ch.it": true,
    "ch.lv": true,
    "ch.pn": true,
    "ch.tc": true,
    "ch.tf": true,
    "ch.vu": true,
    "chambagri.fr": true,
    "championship.aero": true,
    "charter.aero": true,
    "chat.ru": true,
    "chattanooga.museum": true,
    "chel.ru": true,
    "cheltenham.museum": true,
    "chelyabinsk.ru": true,
    "cherkassy.ua": true,
    "chernigov.ua": true,
    "chernovtsy.ua": true,
    "chesapeakebay.museum": true,
    "chiba.jp": true,
    "chicago.museum": true,
    "chieti.it": true,
    "children.museum": true,
    "childrens.museum": true,
    "childrensgarden.museum": true,
    "chiropractic.museum": true,
    "chirurgiens-dentistes.fr": true,
    "chita.ru": true,
    "chocolate.museum": true,
    "christiansburg.museum": true,
    "chukotka.ru": true,
    "chungbuk.kr": true,
    "chungnam.kr": true,
    "chuvashia.ru": true,
    "cieszyn.pl": true,
    "cim.br": true,
    "cincinnati.museum": true,
    "cinema.museum": true,
    "circus.museum": true,
    "city.hu": true,
    "city.za": true,
    "civilaviation.aero": true,
    "civilisation.museum": true,
    "civilization.museum": true,
    "civilwar.museum": true,
    "cjb.net": true,
    "ck.ua": true,
    "cl.it": true,
    "clickbank.net": true,
    "clinton.museum": true,
    "clock.museum": true,
    "club.aero": true,
    "club.tw": true,
    "cmw.ru": true,
    "cn.com": true,
    "cn.im": true,
    "cn.it": true,
    "cn.ms": true,
    "cn.pn": true,
    "cn.ua": true,
    "cng.br": true,
    "cnt.br": true,
    "co.ae": true,
    "co.ag": true,
    "co.am": true,
    "co.ao": true,
    "co.at": true,
    "co.ba": true,
    "co.be": true,
    "co.bi": true,
    "co.bw": true,
    "co.cc": true,
    "co.ci": true,
    "co.ck": true,
    "co.cm": true,
    "co.cr": true,
    "co.cu": true,
    "co.dk": true,
    "co.ee": true,
    "co.fk": true,
    "co.gg": true,
    "co.gy": true,
    "co.hu": true,
    "co.id": true,
    "co.il": true,
    "co.im": true,
    "co.in": true,
    "co.ir": true,
    "co.it": true,
    "co.je": true,
    "co.jp": true,
    "co.ke": true,
    "co.kg": true,
    "co.kr": true,
    "co.lc": true,
    "co.ls": true,
    "co.ma": true,
    "co.me": true,
    "co.mp": true,
    "co.mu": true,
    "co.mw": true,
    "co.mz": true,
    "co.na": true,
    "co.nf": true,
    "co.nu": true,
    "co.nz": true,
    "co.om": true,
    "co.pn": true,
    "co.pw": true,
    "co.rs": true,
    "co.rw": true,
    "co.sh": true,
    "co.st": true,
    "co.sz": true,
    "co.th": true,
    "co.tj": true,
    "co.tm": true,
    "co.tt": true,
    "co.tv": true,
    "co.tz": true,
    "co.ua": true,
    "co.ug": true,
    "co.uk": true,
    "co.us": true,
    "co.uz": true,
    "co.ve": true,
    "co.vi": true,
    "co.yu": true,
    "co.za": true,
    "co.zm": true,
    "co.zw": true,
    "coal.museum": true,
    "coastaldefence.museum": true,
    "cody.museum": true,
    "coldwar.museum": true,
    "collection.museum": true,
    "colonialwilliamsburg.museum": true,
    "coloradoplateau.museum": true,
    "columbia.museum": true,
    "columbus.museum": true,
    "com.ac": true,
    "com.ae": true,
    "com.af": true,
    "com.ag": true,
    "com.ai": true,
    "com.al": true,
    "com.am": true,
    "com.an": true,
    "com.ar": true,
    "com.au": true,
    "com.aw": true,
    "com.az": true,
    "com.ba": true,
    "com.bb": true,
    "com.bd": true,
    "com.bh": true,
    "com.bi": true,
    "com.bm": true,
    "com.bn": true,
    "com.bo": true,
    "com.br": true,
    "com.bs": true,
    "com.bt": true,
    "com.by": true,
    "com.bz": true,
    "com.cd": true,
    "com.ch": true,
    "com.ci": true,
    "com.cm": true,
    "com.cn": true,
    "com.co": true,
    "com.cu": true,
    "com.cy": true,
    "com.de": true,
    "com.dm": true,
    "com.do": true,
    "com.dz": true,
    "com.ec": true,
    "com.ee": true,
    "com.eg": true,
    "com.er": true,
    "com.es": true,
    "com.et": true,
    "com.fj": true,
    "com.fk": true,
    "com.fr": true,
    "com.ge": true,
    "com.gh": true,
    "com.gi": true,
    "com.gn": true,
    "com.gp": true,
    "com.gr": true,
    "com.gt": true,
    "com.gu": true,
    "com.gy": true,
    "com.hk": true,
    "com.hn": true,
    "com.hr": true,
    "com.ht": true,
    "com.io": true,
    "com.iq": true,
    "com.is": true,
    "com.jm": true,
    "com.jo": true,
    "com.kg": true,
    "com.kh": true,
    "com.ki": true,
    "com.km": true,
    "com.kw": true,
    "com.ky": true,
    "com.kz": true,
    "com.la": true,
    "com.lb": true,
    "com.lc": true,
    "com.li": true,
    "com.lk": true,
    "com.lr": true,
    "com.lv": true,
    "com.ly": true,
    "com.mg": true,
    "com.mk": true,
    "com.ml": true,
    "com.mm": true,
    "com.mn": true,
    "com.mo": true,
    "com.mt": true,
    "com.mu": true,
    "com.mv": true,
    "com.mw": true,
    "com.mx": true,
    "com.my": true,
    "com.na": true,
    "com.nc": true,
    "com.nf": true,
    "com.ng": true,
    "com.ni": true,
    "com.np": true,
    "com.nr": true,
    "com.nu": true,
    "com.om": true,
    "com.pa": true,
    "com.pe": true,
    "com.pf": true,
    "com.pg": true,
    "com.ph": true,
    "com.pk": true,
    "com.pl": true,
    "com.pr": true,
    "com.ps": true,
    "com.pt": true,
    "com.py": true,
    "com.qa": true,
    "com.re": true,
    "com.ro": true,
    "com.ru": true,
    "com.rw": true,
    "com.sa": true,
    "com.sb": true,
    "com.sc": true,
    "com.sd": true,
    "com.sg": true,
    "com.sh": true,
    "com.sl": true,
    "com.st": true,
    "com.sv": true,
    "com.sy": true,
    "com.tj": true,
    "com.tm": true,
    "com.tn": true,
    "com.to": true,
    "com.tr": true,
    "com.tt": true,
    "com.tv": true,
    "com.tw": true,
    "com.ua": true,
    "com.uy": true,
    "com.uz": true,
    "com.vc": true,
    "com.ve": true,
    "com.vi": true,
    "com.vn": true,
    "com.vu": true,
    "com.ws": true,
    "com.ye": true,
    "com.zm": true,
    "communication.museum": true,
    "communications.museum": true,
    "community.museum": true,
    "como.it": true,
    "computer.museum": true,
    "computerhistory.museum": true,
    "conf.au": true,
    "conf.lv": true,
    "conference.aero": true,
    "congresodelalengua3.ar": true,
    "consulado.st": true,
    "consultant.aero": true,
    "consulting.aero": true,
    "contemporary.museum": true,
    "contemporaryart.museum": true,
    "control.aero": true,
    "convent.museum": true,
    "coop.br": true,
    "coop.ht": true,
    "coop.km": true,
    "coop.mv": true,
    "coop.mw": true,
    "coop.tt": true,
    "copenhagen.museum": true,
    "corp.st": true,
    "corporation.museum": true,
    "corvette.museum": true,
    "cosenza.it": true,
    "costume.museum": true,
    "council.aero": true,
    "countryestate.museum": true,
    "county.museum": true,
    "cp.cx": true,
    "cpa.pro": true,
    "cq.cn": true,
    "cr.it": true,
    "crafts.museum": true,
    "cranbrook.museum": true,
    "creation.museum": true,
    "cremona.it": true,
    "crew.aero": true,
    "cri.nz": true,
    "crimea.ua": true,
    "crotone.it": true,
    "cs.it": true,
    "csiro.au": true,
    "ct.it": true,
    "ct.us": true,
    "cu.cc": true,
    "cuccfree.com": true,
    "cul.na": true,
    "cultural.museum": true,
    "culturalcenter.museum": true,
    "culture.museum": true,
    "cuneo.it": true,
    "cv.ua": true,
    "cx.cc": true,
    "cyber.museum": true,
    "cymru.museum": true,
    "cyt.cu": true,
    "cz.cc": true,
    "cz.it": true,
    "cz.tc": true,
    "cz.tf": true,
    "cz.tl": true,
    "czeladz.pl": true,
    "czest.pl": true,
    "d.bg": true,
    "d.se": true,
    "daegu.kr": true,
    "daejeon.kr": true,
    "dagestan.ru": true,
    "dali.museum": true,
    "dallas.museum": true,
    "database.museum": true,
    "davvenjarga.no": true,
    "davvesiida.no": true,
    "dc.us": true,
    "ddns.me": true,
    "ddr.museum": true,
    "de.be": true,
    "de.com": true,
    "de.ki": true,
    "de.lv": true,
    "de.ms": true,
    "de.net": true,
    "de.pn": true,
    "de.tc": true,
    "de.tf": true,
    "de.tl": true,
    "de.tt": true,
    "de.us": true,
    "de.vu": true,
    "deatnu.no": true,
    "decorativearts.museum": true,
    "defense.tn": true,
    "delaware.museum": true,
    "delmenhorst.museum": true,
    "denmark.museum": true,
    "dep.no": true,
    "depot.museum": true,
    "design.aero": true,
    "design.museum": true,
    "detroit.museum": true,
    "dgca.aero": true,
    "dielddanuorri.no": true,
    "dinosaur.museum": true,
    "discovery.museum": true,
    "divtasvuodna.no": true,
    "divttasvuotna.no": true,
    "dk.org": true,
    "dk.tc": true,
    "dk.tt": true,
    "dlugoleka.pl": true,
    "dn.ua": true,
    "dnepropetrovsk.ua": true,
    "dni.us": true,
    "dns.be": true,
    "dolls.museum": true,
    "donetsk.ua": true,
    "donna.no": true,
    "donostia.museum": true,
    "dovre.no": true,
    "dp.ua": true,
    "dpn.br": true,
    "dr.na": true,
    "dr.tr": true,
    "drammen.no": true,
    "drangedal.no": true,
    "drobak.no": true,
    "dudinka.ru": true,
    "durham.museum": true,
    "dyndns-at-home.com": true,
    "dyndns-at-work.com": true,
    "dyndns-blog.com": true,
    "dyndns-free.com": true,
    "dyndns-home.com": true,
    "dyndns-ip.com": true,
    "dyndns-mail.com": true,
    "dyndns-office.com": true,
    "dyndns-pics.com": true,
    "dyndns-remote.com": true,
    "dyndns-server.com": true,
    "dyndns-web.com": true,
    "dyndns-wiki.com": true,
    "dyndns-work.com": true,
    "dyndns.biz": true,
    "dyndns.dk": true,
    "dyndns.info": true,
    "dyndns.org": true,
    "dyndns.tv": true,
    "dyndns.ws": true,
    "dyroy.no": true,
    "e-burg.ru": true,
    "e-famoso.it": true,
    "e.bg": true,
    "e.se": true,
    "e12.ve": true,
    "e164.arpa": true,
    "eastafrica.museum": true,
    "eastcoast.museum": true,
    "ebiz.tw": true,
    "ecn.br": true,
    "ed.ao": true,
    "ed.ci": true,
    "ed.cr": true,
    "ed.jp": true,
    "ed.pw": true,
    "edenvale.info": true,
    "edu.ac": true,
    "edu.af": true,
    "edu.ai": true,
    "edu.al": true,
    "edu.am": true,
    "edu.an": true,
    "edu.ar": true,
    "edu.au": true,
    "edu.az": true,
    "edu.ba": true,
    "edu.bb": true,
    "edu.bd": true,
    "edu.bh": true,
    "edu.bi": true,
    "edu.bm": true,
    "edu.bn": true,
    "edu.bo": true,
    "edu.br": true,
    "edu.bs": true,
    "edu.bt": true,
    "edu.bz": true,
    "edu.ci": true,
    "edu.ck": true,
    "edu.cn": true,
    "edu.co": true,
    "edu.cu": true,
    "edu.dm": true,
    "edu.do": true,
    "edu.dz": true,
    "edu.ec": true,
    "edu.ee": true,
    "edu.eg": true,
    "edu.er": true,
    "edu.es": true,
    "edu.et": true,
    "edu.ge": true,
    "edu.gh": true,
    "edu.gi": true,
    "edu.gn": true,
    "edu.gp": true,
    "edu.gr": true,
    "edu.gt": true,
    "edu.gu": true,
    "edu.hk": true,
    "edu.hn": true,
    "edu.ht": true,
    "edu.hu": true,
    "edu.in": true,
    "edu.iq": true,
    "edu.is": true,
    "edu.it": true,
    "edu.jm": true,
    "edu.jo": true,
    "edu.kg": true,
    "edu.kh": true,
    "edu.ki": true,
    "edu.km": true,
    "edu.kn": true,
    "edu.kw": true,
    "edu.ky": true,
    "edu.kz": true,
    "edu.la": true,
    "edu.lb": true,
    "edu.lc": true,
    "edu.lk": true,
    "edu.lr": true,
    "edu.lv": true,
    "edu.ly": true,
    "edu.me": true,
    "edu.mg": true,
    "edu.mk": true,
    "edu.ml": true,
    "edu.mm": true,
    "edu.mn": true,
    "edu.mo": true,
    "edu.mp": true,
    "edu.mt": true,
    "edu.mv": true,
    "edu.mw": true,
    "edu.mx": true,
    "edu.my": true,
    "edu.na": true,
    "edu.ng": true,
    "edu.ni": true,
    "edu.np": true,
    "edu.nr": true,
    "edu.om": true,
    "edu.pa": true,
    "edu.pe": true,
    "edu.pf": true,
    "edu.ph": true,
    "edu.pk": true,
    "edu.pl": true,
    "edu.pn": true,
    "edu.pr": true,
    "edu.ps": true,
    "edu.pt": true,
    "edu.py": true,
    "edu.qa": true,
    "edu.rs": true,
    "edu.ru": true,
    "edu.rw": true,
    "edu.sa": true,
    "edu.sb": true,
    "edu.sc": true,
    "edu.sd": true,
    "edu.sg": true,
    "edu.sh": true,
    "edu.sk": true,
    "edu.sl": true,
    "edu.st": true,
    "edu.sv": true,
    "edu.sy": true,
    "edu.tc": true,
    "edu.tf": true,
    "edu.tj": true,
    "edu.to": true,
    "edu.tr": true,
    "edu.tt": true,
    "edu.tw": true,
    "edu.ua": true,
    "edu.uk": true,
    "edu.uy": true,
    "edu.vc": true,
    "edu.ve": true,
    "edu.vi": true,
    "edu.vn": true,
    "edu.vu": true,
    "edu.ws": true,
    "edu.ye": true,
    "edu.yu": true,
    "edu.za": true,
    "edu.zm": true,
    "educ.ar": true,
    "education.museum": true,
    "educational.museum": true,
    "educator.aero": true,
    "edunet.tn": true,
    "egersund.no": true,
    "egyptian.museum": true,
    "ehime.jp": true,
    "eid.no": true,
    "eidfjord.no": true,
    "eidsberg.no": true,
    "eidskog.no": true,
    "eidsvoll.no": true,
    "eigersund.no": true,
    "eisenbahn.museum": true,
    "ekloges.cy": true,
    "elblag.pl": true,
    "elburg.museum": true,
    "elk.pl": true,
    "elvendrell.museum": true,
    "elverum.no": true,
    "embaixada.st": true,
    "embroidery.museum": true,
    "emergency.aero": true,
    "en.it": true,
    "encyclopedic.museum": true,
    "enebakk.no": true,
    "eng.br": true,
    "eng.pro": true,
    "engerdal.no": true,
    "engine.aero": true,
    "engineer.aero": true,
    "england.museum": true,
    "enna.it": true,
    "ens.tn": true,
    "entertainment.aero": true,
    "entomology.museum": true,
    "environment.museum": true,
    "environmentalconservation.museum": true,
    "epilepsy.museum": true,
    "equipment.aero": true,
    "ernet.in": true,
    "erotica.hu": true,
    "erotika.hu": true,
    "es.kr": true,
    "es.pn": true,
    "es.tc": true,
    "es.tl": true,
    "es.tt": true,
    "esp.br": true,
    "essex.museum": true,
    "est.pr": true,
    "estate.museum": true,
    "etc.br": true,
    "ethnology.museum": true,
    "eti.br": true,
    "etne.no": true,
    "etnedal.no": true,
    "eu.com": true,
    "eu.im": true,
    "eu.int": true,
    "eu.org": true,
    "eu.tc": true,
    "eu.tf": true,
    "eu.tt": true,
    "eun.eg": true,
    "euro.tm": true,
    "evenassi.no": true,
    "evenes.no": true,
    "evje-og-hornnes.no": true,
    "exchange.aero": true,
    "exeter.museum": true,
    "exhibition.museum": true,
    "experts-comptables.fr": true,
    "express.aero": true,
    "extra.hu": true,
    "f.bg": true,
    "f.se": true,
    "fam.pk": true,
    "family.museum": true,
    "far.br": true,
    "fareast.ru": true,
    "farm.museum": true,
    "farmequipment.museum": true,
    "farmers.museum": true,
    "farmstead.museum": true,
    "farsund.no": true,
    "fauske.no": true,
    "fax.nr": true,
    "fc.it": true,
    "fe.it": true,
    "fed.us": true,
    "federation.aero": true,
    "fedje.no": true,
    "fermo.it": true,
    "ferrara.it": true,
    "fet.no": true,
    "fetsund.no": true,
    "fg.it": true,
    "fgov.be": true,
    "fh.se": true,
    "fhs.no": true,
    "fhsk.se": true,
    "fhv.se": true,
    "fi.cr": true,
    "fi.it": true,
    "fie.ee": true,
    "field.museum": true,
    "figueres.museum": true,
    "filatelia.museum": true,
    "film.hu": true,
    "film.museum": true,
    "fin.ec": true,
    "fin.tn": true,
    "fineart.museum": true,
    "finearts.museum": true,
    "finland.museum": true,
    "finnoy.no": true,
    "firenze.it": true,
    "firm.co": true,
    "firm.ht": true,
    "firm.in": true,
    "firm.nf": true,
    "firm.ro": true,
    "firm.ve": true,
    "fitjar.no": true,
    "fj.cn": true,
    "fjaler.no": true,
    "fjell.no": true,
    "fl.us": true,
    "fla.no": true,
    "flakstad.no": true,
    "flanders.museum": true,
    "flatanger.no": true,
    "flekkefjord.no": true,
    "flesberg.no": true,
    "flight.aero": true,
    "flog.br": true,
    "flora.no": true,
    "florence.it": true,
    "florida.museum": true,
    "floro.no": true,
    "fm.br": true,
    "fm.no": true,
    "fnd.br": true,
    "foggia.it": true,
    "folkebibl.no": true,
    "folldal.no": true,
    "force.museum": true,
    "forde.no": true,
    "forli-cesena.it": true,
    "forlicesena.it": true,
    "forsand.no": true,
    "fortmissoula.museum": true,
    "fortworth.museum": true,
    "forum.hu": true,
    "fosnes.no": true,
    "fot.br": true,
    "foundation.museum": true,
    "fr.cr": true,
    "fr.it": true,
    "fr.ms": true,
    "fr.nf": true,
    "fr.pn": true,
    "fr.tc": true,
    "fr.tt": true,
    "fr.vu": true,
    "frana.no": true,
    "francaise.museum": true,
    "frankfurt.museum": true,
    "franziskaner.museum": true,
    "fredrikstad.no": true,
    "free.fr": true,
    "freehostia.com": true,
    "freemasonry.museum": true,
    "freeservercity.com": true,
    "frei.no": true,
    "freiburg.museum": true,
    "freight.aero": true,
    "fribourg.museum": true,
    "frog.museum": true,
    "frogn.no": true,
    "froland.no": true,
    "from.hr": true,
    "fromru.su": true,
    "front.ru": true,
    "frosinone.it": true,
    "frosta.no": true,
    "froya.no": true,
    "fst.br": true,
    "fuel.aero": true,
    "fukui.jp": true,
    "fukuoka.jp": true,
    "fukushima.jp": true,
    "fundacio.museum": true,
    "funpic.de": true,
    "fuoisku.no": true,
    "fuossko.no": true,
    "furniture.museum": true,
    "fusa.no": true,
    "fx.to": true,
    "fylkesbibl.no": true,
    "fyresdal.no": true,
    "g.bg": true,
    "g.se": true,
    "g12.br": true,
    "ga.us": true,
    "gaivuotna.no": true,
    "gallery.museum": true,
    "galsa.no": true,
    "game.tw": true,
    "games.hu": true,
    "gamvik.no": true,
    "gangaviika.no": true,
    "gangwon.kr": true,
    "garden.museum": true,
    "gateway.museum": true,
    "gaular.no": true,
    "gausdal.no": true,
    "gb.com": true,
    "gb.net": true,
    "gbr.me": true,
    "gc.ca": true,
    "gd.cn": true,
    "gda.pl": true,
    "gdansk.pl": true,
    "gdynia.pl": true,
    "ge.it": true,
    "geek.nz": true,
    "geelvinck.museum": true,
    "gemological.museum": true,
    "gen.in": true,
    "gen.nz": true,
    "gen.tr": true,
    "genoa.it": true,
    "genova.it": true,
    "geocities.com": true,
    "geocities.jp": true,
    "geology.museum": true,
    "geometre-expert.fr": true,
    "georgia.museum": true,
    "get.cu": true,
    "getmyip.com": true,
    "ggf.br": true,
    "giehtavuoatna.no": true,
    "giessen.museum": true,
    "gifu.jp": true,
    "gigazu.net": true,
    "gildeskal.no": true,
    "giske.no": true,
    "gjemnes.no": true,
    "gjerdrum.no": true,
    "gjerstad.no": true,
    "gjesdal.no": true,
    "gjovik.no": true,
    "glas.museum": true,
    "glass.museum": true,
    "gliding.aero": true,
    "gliwice.pl": true,
    "glogow.pl": true,
    "gloppen.no": true,
    "gmina.pl": true,
    "gmxhome.de": true,
    "gniezno.pl": true,
    "go.ci": true,
    "go.com": true,
    "go.cr": true,
    "go.id": true,
    "go.it": true,
    "go.jp": true,
    "go.ke": true,
    "go.kr": true,
    "go.pw": true,
    "go.ro": true,
    "go.th": true,
    "go.tj": true,
    "go.tz": true,
    "go.ug": true,
    "gob.ar": true,
    "gob.bo": true,
    "gob.cl": true,
    "gob.do": true,
    "gob.ec": true,
    "gob.es": true,
    "gob.gt": true,
    "gob.hn": true,
    "gob.mx": true,
    "gob.ni": true,
    "gob.pa": true,
    "gob.pe": true,
    "gob.pk": true,
    "gob.sv": true,
    "gob.ve": true,
    "gobiernoelectronico.ar": true,
    "gok.pk": true,
    "gol.no": true,
    "gon.pk": true,
    "googlegroups.com": true,
    "googlepages.com": true,
    "gop.pk": true,
    "gorge.museum": true,
    "gorizia.it": true,
    "gorlice.pl": true,
    "gos.pk": true,
    "gouv.ci": true,
    "gouv.fr": true,
    "gouv.ht": true,
    "gouv.km": true,
    "gouv.ml": true,
    "gouv.rw": true,
    "gov.ac": true,
    "gov.ae": true,
    "gov.af": true,
    "gov.ai": true,
    "gov.al": true,
    "gov.am": true,
    "gov.ar": true,
    "gov.as": true,
    "gov.au": true,
    "gov.az": true,
    "gov.ba": true,
    "gov.bb": true,
    "gov.bd": true,
    "gov.bf": true,
    "gov.bh": true,
    "gov.bm": true,
    "gov.bn": true,
    "gov.bo": true,
    "gov.br": true,
    "gov.bs": true,
    "gov.bt": true,
    "gov.by": true,
    "gov.bz": true,
    "gov.cd": true,
    "gov.ch": true,
    "gov.ck": true,
    "gov.cl": true,
    "gov.cm": true,
    "gov.cn": true,
    "gov.co": true,
    "gov.cu": true,
    "gov.cx": true,
    "gov.cy": true,
    "gov.dm": true,
    "gov.do": true,
    "gov.dz": true,
    "gov.ec": true,
    "gov.ee": true,
    "gov.eg": true,
    "gov.er": true,
    "gov.et": true,
    "gov.fj": true,
    "gov.fk": true,
    "gov.ge": true,
    "gov.gg": true,
    "gov.gh": true,
    "gov.gi": true,
    "gov.gn": true,
    "gov.gr": true,
    "gov.gu": true,
    "gov.hk": true,
    "gov.hu": true,
    "gov.ie": true,
    "gov.il": true,
    "gov.im": true,
    "gov.in": true,
    "gov.io": true,
    "gov.iq": true,
    "gov.ir": true,
    "gov.is": true,
    "gov.it": true,
    "gov.je": true,
    "gov.jm": true,
    "gov.jo": true,
    "gov.jp": true,
    "gov.kg": true,
    "gov.kh": true,
    "gov.ki": true,
    "gov.km": true,
    "gov.kn": true,
    "gov.kw": true,
    "gov.ky": true,
    "gov.kz": true,
    "gov.la": true,
    "gov.lb": true,
    "gov.lc": true,
    "gov.li": true,
    "gov.lk": true,
    "gov.lr": true,
    "gov.lt": true,
    "gov.lu": true,
    "gov.lv": true,
    "gov.ly": true,
    "gov.ma": true,
    "gov.me": true,
    "gov.mg": true,
    "gov.mk": true,
    "gov.ml": true,
    "gov.mm": true,
    "gov.mn": true,
    "gov.mo": true,
    "gov.mp": true,
    "gov.mr": true,
    "gov.mt": true,
    "gov.mu": true,
    "gov.mv": true,
    "gov.mw": true,
    "gov.my": true,
    "gov.ng": true,
    "gov.np": true,
    "gov.nr": true,
    "gov.om": true,
    "gov.ph": true,
    "gov.pk": true,
    "gov.pl": true,
    "gov.pn": true,
    "gov.pr": true,
    "gov.ps": true,
    "gov.pt": true,
    "gov.py": true,
    "gov.qa": true,
    "gov.rs": true,
    "gov.ru": true,
    "gov.rw": true,
    "gov.sa": true,
    "gov.sb": true,
    "gov.sc": true,
    "gov.sd": true,
    "gov.sg": true,
    "gov.sh": true,
    "gov.sk": true,
    "gov.sl": true,
    "gov.st": true,
    "gov.sy": true,
    "gov.tj": true,
    "gov.tl": true,
    "gov.tm": true,
    "gov.tn": true,
    "gov.to": true,
    "gov.tp": true,
    "gov.tr": true,
    "gov.tt": true,
    "gov.tv": true,
    "gov.tw": true,
    "gov.ua": true,
    "gov.uk": true,
    "gov.vc": true,
    "gov.ve": true,
    "gov.vi": true,
    "gov.vn": true,
    "gov.ws": true,
    "gov.ye": true,
    "gov.za": true,
    "gov.zm": true,
    "gov.zw": true,
    "government.aero": true,
    "government.pn": true,
    "govt.nz": true,
    "gr.com": true,
    "gr.it": true,
    "gr.jp": true,
    "grajewo.pl": true,
    "gran.no": true,
    "grandrapids.museum": true,
    "grane.no": true,
    "granvin.no": true,
    "gratangen.no": true,
    "gratishost.com": true,
    "graz.museum": true,
    "greta.fr": true,
    "grimstad.no": true,
    "grong.no": true,
    "grosseto.it": true,
    "groundhandling.aero": true,
    "group.aero": true,
    "grouply.com": true,
    "grozny.ru": true,
    "grp.lk": true,
    "grue.no": true,
    "gs.cn": true,
    "gsm.pl": true,
    "gu.us": true,
    "gub.uy": true,
    "guernsey.gg": true,
    "guernsey.museum": true,
    "gulen.no": true,
    "gunma.jp": true,
    "guovdageaidnu.no": true,
    "gv.ao": true,
    "gv.at": true,
    "gv.vg": true,
    "gwangju.kr": true,
    "gx.cn": true,
    "gyeongbuk.kr": true,
    "gyeonggi.kr": true,
    "gyeongnam.kr": true,
    "gz.cn": true,
    "h.bg": true,
    "h.se": true,
    "ha.cn": true,
    "ha.no": true,
    "habmer.no": true,
    "hadsel.no": true,
    "hagebostad.no": true,
    "halden.no": true,
    "halloffame.museum": true,
    "halsa.no": true,
    "hamar.no": true,
    "hamaroy.no": true,
    "hamburg.museum": true,
    "hammarfeasta.no": true,
    "hammerfest.no": true,
    "handson.museum": true,
    "hanggliding.aero": true,
    "hapmir.no": true,
    "haram.no": true,
    "hareid.no": true,
    "harstad.no": true,
    "harvestcelebration.museum": true,
    "hasvik.no": true,
    "hattfjelldal.no": true,
    "haugesund.no": true,
    "hawaii.museum": true,
    "hb.cn": true,
    "he.cn": true,
    "health.museum": true,
    "health.vn": true,
    "heimatunduhren.museum": true,
    "hellas.museum": true,
    "helloweb.eu": true,
    "helsinki.museum": true,
    "hembygdsforbund.museum": true,
    "hemne.no": true,
    "hemnes.no": true,
    "hemsedal.no": true,
    "herad.no": true,
    "heritage.museum": true,
    "hi.cn": true,
    "hi.us": true,
    "hiroshima.jp": true,
    "histoire.museum": true,
    "historical.museum": true,
    "historicalsociety.museum": true,
    "historichouses.museum": true,
    "historisch.museum": true,
    "historisches.museum": true,
    "history.museum": true,
    "historyofscience.museum": true,
    "hitra.no": true,
    "hjartdal.no": true,
    "hjelmeland.no": true,
    "hk.cn": true,
    "hk.ms": true,
    "hk.tc": true,
    "hk.vg": true,
    "hl.cn": true,
    "hl.no": true,
    "hm.no": true,
    "hn.cn": true,
    "hobol.no": true,
    "hof.no": true,
    "hokkaido.jp": true,
    "hokksund.no": true,
    "hol.no": true,
    "hole.no": true,
    "holmestrand.no": true,
    "holtalen.no": true,
    "home.pl": true,
    "home.ro": true,
    "homebuilt.aero": true,
    "homeip.net": true,
    "honefoss.no": true,
    "hornindal.no": true,
    "horology.museum": true,
    "horten.no": true,
    "host.sk": true,
    "hostevo.com": true,
    "hotbox.ru": true,
    "hotel.hu": true,
    "hotel.lk": true,
    "hotmail.ru": true,
    "house.museum": true,
    "hoyanger.no": true,
    "hoylandet.no": true,
    "hs.kr": true,
    "hu.com": true,
    "hu.tc": true,
    "hu2.ru": true,
    "huissier-justice.fr": true,
    "humanities.museum": true,
    "hurdal.no": true,
    "hurum.no": true,
    "hut2.ru": true,
    "hvaler.no": true,
    "hyllestad.no": true,
    "hyogo.jp": true,
    "i.bg": true,
    "i.ph": true,
    "i.se": true,
    "ia.us": true,
    "ibaraki.jp": true,
    "ibelgique.com": true,
    "ibestad.no": true,
    "ibiz.cc": true,
    "iblogger.org": true,
    "ic.cz": true,
    "icnet.uk": true,
    "id.au": true,
    "id.fj": true,
    "id.ir": true,
    "id.lv": true,
    "id.ly": true,
    "id.ru": true,
    "id.us": true,
    "idf.il": true,
    "idn.sg": true,
    "idoo.com": true,
    "idrett.no": true,
    "idv.hk": true,
    "idv.tw": true,
    "ie.tc": true,
    "iespana.es": true,
    "if.ua": true,
    "ifrance.com": true,
    "iim.bz": true,
    "il.im": true,
    "il.us": true,
    "ilawa.pl": true,
    "illustration.museum": true,
    "im.it": true,
    "imageandsound.museum": true,
    "imb.br": true,
    "imperia.it": true,
    "in.na": true,
    "in.rs": true,
    "in.th": true,
    "in.ua": true,
    "in.us": true,
    "incheon.kr": true,
    "ind.br": true,
    "ind.er": true,
    "ind.gg": true,
    "ind.gt": true,
    "ind.in": true,
    "ind.je": true,
    "ind.tn": true,
    "inderoy.no": true,
    "indian.museum": true,
    "indiana.museum": true,
    "indianapolis.museum": true,
    "indianmarket.museum": true,
    "inf.br": true,
    "inf.cu": true,
    "inf.mk": true,
    "info.au": true,
    "info.az": true,
    "info.bh": true,
    "info.co": true,
    "info.cu": true,
    "info.cy": true,
    "info.ec": true,
    "info.et": true,
    "info.fj": true,
    "info.ht": true,
    "info.hu": true,
    "info.ki": true,
    "info.la": true,
    "info.ms": true,
    "info.mv": true,
    "info.na": true,
    "info.nf": true,
    "info.nr": true,
    "info.pk": true,
    "info.pl": true,
    "info.pr": true,
    "info.ro": true,
    "info.sd": true,
    "info.tn": true,
    "info.tr": true,
    "info.tt": true,
    "info.ve": true,
    "info.vn": true,
    "infos.st": true,
    "ing.pa": true,
    "ingatlan.hu": true,
    "inima.al": true,
    "insurance.aero": true,
    "int.am": true,
    "int.ar": true,
    "int.az": true,
    "int.bo": true,
    "int.ci": true,
    "int.co": true,
    "int.is": true,
    "int.la": true,
    "int.lk": true,
    "int.mv": true,
    "int.mw": true,
    "int.pt": true,
    "int.ru": true,
    "int.rw": true,
    "int.tc": true,
    "int.tf": true,
    "int.tj": true,
    "int.tt": true,
    "int.ve": true,
    "int.vn": true,
    "intelligence.museum": true,
    "interactive.museum": true,
    "interia.pl": true,
    "interii.pl": true,
    "intl.tn": true,
    "ip6.arpa": true,
    "iquebec.com": true,
    "iraq.museum": true,
    "irc.pl": true,
    "iris.arpa": true,
    "irkutsk.ru": true,
    "iron.museum": true,
    "is.it": true,
    "isa.us": true,
    "isernia.it": true,
    "ishikawa.jp": true,
    "isla.pr": true,
    "isleofman.museum": true,
    "isuisse.com": true,
    "it.ao": true,
    "it.pn": true,
    "it.tc": true,
    "it.tt": true,
    "its.me": true,
    "ivano-frankivsk.ua": true,
    "ivanovo.ru": true,
    "iveland.no": true,
    "ivgu.no": true,
    "iwate.jp": true,
    "iwebsource.com": true,
    "iwi.nz": true,
    "iz.hr": true,
    "izhevsk.ru": true,
    "j.bg": true,
    "jamal.ru": true,
    "jamison.museum": true,
    "jan-mayen.no": true,
    "jar.ru": true,
    "jaworzno.pl": true,
    "jefferson.museum": true,
    "jeju.kr": true,
    "jelenia-gora.pl": true,
    "jeonbuk.kr": true,
    "jeonnam.kr": true,
    "jersey.je": true,
    "jerusalem.museum": true,
    "jessheim.no": true,
    "jet.uk": true,
    "jevnaker.no": true,
    "jewelry.museum": true,
    "jewish.museum": true,
    "jewishart.museum": true,
    "jfk.museum": true,
    "jgora.pl": true,
    "jimdo.com": true,
    "jino-net.ru": true,
    "jl.cn": true,
    "jobs.tt": true,
    "jogasz.hu": true,
    "jolster.no": true,
    "jondal.no": true,
    "jor.br": true,
    "jorpeland.no": true,
    "joshkar-ola.ru": true,
    "journal.aero": true,
    "journalism.museum": true,
    "journalist.aero": true,
    "jp.net": true,
    "jp.pn": true,
    "jpn.com": true,
    "js.cn": true,
    "judaica.museum": true,
    "judygarland.museum": true,
    "juedisches.museum": true,
    "juif.museum": true,
    "jur.pro": true,
    "jus.br": true,
    "jx.cn": true,
    "k-uralsk.ru": true,
    "k.bg": true,
    "k.se": true,
    "k12.ec": true,
    "k12.il": true,
    "k12.tr": true,
    "k12.vi": true,
    "kafjord.no": true,
    "kagawa.jp": true,
    "kagoshima.jp": true,
    "kalisz.pl": true,
    "kalmykia.ru": true,
    "kaluga.ru": true,
    "kamchatka.ru": true,
    "kanagawa.jp": true,
    "kanazawa.jp": true,
    "karasjohka.no": true,
    "karasjok.no": true,
    "karate.museum": true,
    "karelia.ru": true,
    "karikatur.museum": true,
    "karlsoy.no": true,
    "karmoy.no": true,
    "karpacz.pl": true,
    "kartuzy.pl": true,
    "kaszuby.pl": true,
    "katowice.pl": true,
    "kautokeino.no": true,
    "kawasaki.jp": true,
    "kazan.ru": true,
    "kazimierz-dolny.pl": true,
    "kchr.ru": true,
    "kemerovo.ru": true,
    "kepno.pl": true,
    "ketrzyn.pl": true,
    "kg.kr": true,
    "kh.ua": true,
    "khabarovsk.ru": true,
    "khakassia.ru": true,
    "kharkov.ua": true,
    "kherson.ua": true,
    "khmelnitskiy.ua": true,
    "khv.ru": true,
    "kickme.to": true,
    "kids.museum": true,
    "kids.us": true,
    "kiev.ua": true,
    "kimsufi.com": true,
    "kirkenes.no": true,
    "kirov.ru": true,
    "kirovograd.ua": true,
    "kitakyushu.jp": true,
    "klabu.no": true,
    "klepp.no": true,
    "klodzko.pl": true,
    "km.ua": true,
    "kms.ru": true,
    "kobe.jp": true,
    "kobierzyce.pl": true,
    "kochi.jp": true,
    "koebenhavn.museum": true,
    "koeln.museum": true,
    "koenig.ru": true,
    "kolobrzeg.pl": true,
    "komforb.se": true,
    "komi.ru": true,
    "kommunalforbund.se": true,
    "kommune.no": true,
    "komvux.se": true,
    "kongsberg.no": true,
    "kongsvinger.no": true,
    "konin.pl": true,
    "konskowola.pl": true,
    "konyvelo.hu": true,
    "kopervik.no": true,
    "kostroma.ru": true,
    "kr.com": true,
    "kr.it": true,
    "kr.tc": true,
    "kr.ua": true,
    "kraanghke.no": true,
    "kragero.no": true,
    "krakow.pl": true,
    "krasnoyarsk.ru": true,
    "kristiansand.no": true,
    "kristiansund.no": true,
    "krodsherad.no": true,
    "krokstadelva.no": true,
    "krovatka.su": true,
    "ks.ua": true,
    "ks.us": true,
    "kuban.ru": true,
    "kumamoto.jp": true,
    "kunst.museum": true,
    "kunstsammlung.museum": true,
    "kunstunddesign.museum": true,
    "kurgan.ru": true,
    "kursk.ru": true,
    "kustanai.ru": true,
    "kutno.pl": true,
    "kuzbass.ru": true,
    "kv.ua": true,
    "kvafjord.no": true,
    "kvalsund.no": true,
    "kvam.no": true,
    "kvanangen.no": true,
    "kvinesdal.no": true,
    "kvinnherad.no": true,
    "kviteseid.no": true,
    "kvitsoy.no": true,
    "kwik.to": true,
    "ky.us": true,
    "kyonggi.kr": true,
    "kyoto.jp": true,
    "l.bg": true,
    "l.se": true,
    "la-spezia.it": true,
    "la.us": true,
    "laakesvuemie.no": true,
    "labor.museum": true,
    "labour.museum": true,
    "lahppi.no": true,
    "lajolla.museum": true,
    "lakas.hu": true,
    "lanarb.se": true,
    "lanbib.se": true,
    "lancashire.museum": true,
    "land.ru": true,
    "landes.museum": true,
    "langevag.no": true,
    "lans.museum": true,
    "lapy.pl": true,
    "laquila.it": true,
    "lardal.no": true,
    "larsson.museum": true,
    "larvik.no": true,
    "laspezia.it": true,
    "latina.it": true,
    "lavagis.no": true,
    "lavangen.no": true,
    "law.pro": true,
    "law.za": true,
    "lc.it": true,
    "le.it": true,
    "leangaviika.no": true,
    "leasing.aero": true,
    "lebesby.no": true,
    "lebork.pl": true,
    "lecce.it": true,
    "lecco.it": true,
    "legnica.pl": true,
    "leikanger.no": true,
    "leirfjord.no": true,
    "leirvik.no": true,
    "leka.no": true,
    "leksvik.no": true,
    "lel.br": true,
    "lenvik.no": true,
    "lerdal.no": true,
    "lesja.no": true,
    "levanger.no": true,
    "lewismiller.museum": true,
    "lezajsk.pl": true,
    "lg.jp": true,
    "lg.ua": true,
    "li.it": true,
    "lib.ee": true,
    "lier.no": true,
    "lierne.no": true,
    "lillehammer.no": true,
    "lillesand.no": true,
    "limanowa.pl": true,
    "limewebs.com": true,
    "lincoln.museum": true,
    "lindas.no": true,
    "lindesnes.no": true,
    "linz.museum": true,
    "lipetsk.ru": true,
    "livejournal.com": true,
    "living.museum": true,
    "livinghistory.museum": true,
    "livorno.it": true,
    "ln.cn": true,
    "lo.it": true,
    "loabat.no": true,
    "localhistory.museum": true,
    "lodi.it": true,
    "lodingen.no": true,
    "lodz.pl": true,
    "logistics.aero": true,
    "lom.no": true,
    "lomza.pl": true,
    "london.museum": true,
    "loppa.no": true,
    "lorenskog.no": true,
    "losangeles.museum": true,
    "loten.no": true,
    "louvre.museum": true,
    "lowicz.pl": true,
    "loyalist.museum": true,
    "lt.it": true,
    "ltd.cy": true,
    "ltd.gg": true,
    "ltd.gi": true,
    "ltd.je": true,
    "ltd.lk": true,
    "ltd.uk": true,
    "lu.it": true,
    "lubin.pl": true,
    "lublin.pl": true,
    "lucca.it": true,
    "lucerne.museum": true,
    "lugansk.ua": true,
    "lukow.pl": true,
    "lund.no": true,
    "lunner.no": true,
    "luroy.no": true,
    "luster.no": true,
    "lutsk.ua": true,
    "luxembourg.museum": true,
    "luzern.museum": true,
    "lviv.ua": true,
    "lyngdal.no": true,
    "lyngen.no": true,
    "m.bg": true,
    "m.se": true,
    "ma.us": true,
    "macerata.it": true,
    "mad.museum": true,
    "madrid.museum": true,
    "magadan.ru": true,
    "magazine.aero": true,
    "magnitka.ru": true,
    "mail.pl": true,
    "mail.ru": true,
    "mail15.su": true,
    "mail2k.ru": true,
    "mail333.su": true,
    "maintenance.aero": true,
    "malatvuopmi.no": true,
    "malbork.pl": true,
    "mallorca.museum": true,
    "malopolska.pl": true,
    "malselv.no": true,
    "malvik.no": true,
    "manchester.museum": true,
    "mandal.no": true,
    "mansion.museum": true,
    "mansions.museum": true,
    "mantova.it": true,
    "manx.museum": true,
    "maori.nz": true,
    "marburg.museum": true,
    "mari-el.ru": true,
    "mari.ru": true,
    "marine.ru": true,
    "maritime.museum": true,
    "maritimo.museum": true,
    "marker.no": true,
    "marketplace.aero": true,
    "marnardal.no": true,
    "maryland.museum": true,
    "marylhurst.museum": true,
    "masfjorden.no": true,
    "masoy.no": true,
    "massa-carrara.it": true,
    "massacarrara.it": true,
    "mat.br": true,
    "matera.it": true,
    "matsuyama.jp": true,
    "matta-varjjat.no": true,
    "mazowsze.pl": true,
    "mazury.pl": true,
    "mb.ca": true,
    "mbone.pl": true,
    "mc.it": true,
    "md.ci": true,
    "md.us": true,
    "me.it": true,
    "me.uk": true,
    "me.us": true,
    "mecon.ar": true,
    "med.br": true,
    "med.ec": true,
    "med.ee": true,
    "med.ht": true,
    "med.ly": true,
    "med.om": true,
    "med.pa": true,
    "med.pl": true,
    "med.pro": true,
    "med.sa": true,
    "med.sd": true,
    "medecin.fr": true,
    "medecin.km": true,
    "media.aero": true,
    "media.hu": true,
    "media.museum": true,
    "media.pl": true,
    "medical.museum": true,
    "medizinhistorisches.museum": true,
    "meeres.museum": true,
    "meland.no": true,
    "meldal.no": true,
    "melhus.no": true,
    "meloy.no": true,
    "memorial.museum": true,
    "meraker.no": true,
    "mesaverde.museum": true,
    "messina.it": true,
    "mi.it": true,
    "mi.th": true,
    "mi.us": true,
    "miasta.pl": true,
    "michigan.museum": true,
    "microlight.aero": true,
    "midatlantic.museum": true,
    "midsund.no": true,
    "midtre-gauldal.no": true,
    "mie.jp": true,
    "mielec.pl": true,
    "mielno.pl": true,
    "mil.ac": true,
    "mil.ae": true,
    "mil.am": true,
    "mil.ar": true,
    "mil.az": true,
    "mil.ba": true,
    "mil.bd": true,
    "mil.bo": true,
    "mil.br": true,
    "mil.by": true,
    "mil.cn": true,
    "mil.co": true,
    "mil.do": true,
    "mil.ec": true,
    "mil.eg": true,
    "mil.er": true,
    "mil.fj": true,
    "mil.ge": true,
    "mil.gh": true,
    "mil.gt": true,
    "mil.gu": true,
    "mil.hn": true,
    "mil.id": true,
    "mil.in": true,
    "mil.io": true,
    "mil.iq": true,
    "mil.jo": true,
    "mil.kg": true,
    "mil.kh": true,
    "mil.km": true,
    "mil.kr": true,
    "mil.kw": true,
    "mil.kz": true,
    "mil.lb": true,
    "mil.lt": true,
    "mil.lu": true,
    "mil.lv": true,
    "mil.mg": true,
    "mil.mv": true,
    "mil.my": true,
    "mil.no": true,
    "mil.np": true,
    "mil.nz": true,
    "mil.om": true,
    "mil.pe": true,
    "mil.ph": true,
    "mil.pl": true,
    "mil.ru": true,
    "mil.rw": true,
    "mil.se": true,
    "mil.sh": true,
    "mil.sk": true,
    "mil.st": true,
    "mil.sy": true,
    "mil.tj": true,
    "mil.tm": true,
    "mil.to": true,
    "mil.tr": true,
    "mil.tw": true,
    "mil.uk": true,
    "mil.uy": true,
    "mil.vc": true,
    "mil.ve": true,
    "mil.ye": true,
    "mil.za": true,
    "milan.it": true,
    "milano.it": true,
    "military.museum": true,
    "mill.museum": true,
    "mincom.tn": true,
    "mine.nu": true,
    "miners.museum": true,
    "mining.museum": true,
    "minnesota.museum": true,
    "missile.museum": true,
    "missoula.museum": true,
    "miyagi.jp": true,
    "miyazaki.jp": true,
    "mjondalen.no": true,
    "mk.ua": true,
    "mn.it": true,
    "mn.us": true,
    "mo-i-rana.no": true,
    "mo.cn": true,
    "mo.it": true,
    "mo.us": true,
    "moareke.no": true,
    "mob.nr": true,
    "mobi.gp": true,
    "mobi.na": true,
    "mobi.tt": true,
    "mobil.nr": true,
    "mobile.nr": true,
    "mod.gi": true,
    "mod.om": true,
    "mod.uk": true,
    "modalen.no": true,
    "modelling.aero": true,
    "modena.it": true,
    "modern.museum": true,
    "modum.no": true,
    "molde.no": true,
    "moma.museum": true,
    "money.museum": true,
    "monmouth.museum": true,
    "monticello.museum": true,
    "montreal.museum": true,
    "monza.it": true,
    "mooo.com": true,
    "mordovia.ru": true,
    "moscow.museum": true,
    "mosjoen.no": true,
    "moskenes.no": true,
    "mosreg.ru": true,
    "moss.no": true,
    "mosvik.no": true,
    "motorcycle.museum": true,
    "mr.no": true,
    "mragowo.pl": true,
    "ms.it": true,
    "ms.kr": true,
    "ms.us": true,
    "msk.ru": true,
    "mt.it": true,
    "mt.us": true,
    "muenchen.museum": true,
    "muenster.museum": true,
    "mulhouse.museum": true,
    "muncie.museum": true,
    "muni.il": true,
    "muosat.no": true,
    "murmansk.ru": true,
    "mus.br": true,
    "museet.museum": true,
    "museum.mn": true,
    "museum.mv": true,
    "museum.mw": true,
    "museum.no": true,
    "museum.om": true,
    "museum.tt": true,
    "museumcenter.museum": true,
    "museumvereniging.museum": true,
    "music.mobi": true,
    "music.museum": true,
    "mx.na": true,
    "mx.tc": true,
    "mydyndns.org": true,
    "mytis.ru": true,
    "myvnc.com": true,
    "n.bg": true,
    "n.se": true,
    "na.by": true,
    "na.it": true,
    "naamesjevuemie.no": true,
    "nacion.ar": true,
    "nagano.jp": true,
    "nagasaki.jp": true,
    "nagoya.jp": true,
    "nakhodka.ru": true,
    "naklo.pl": true,
    "nalchik.ru": true,
    "namdalseid.no": true,
    "name.ae": true,
    "name.az": true,
    "name.cy": true,
    "name.et": true,
    "name.fj": true,
    "name.hr": true,
    "name.jo": true,
    "name.mk": true,
    "name.mv": true,
    "name.my": true,
    "name.na": true,
    "name.pr": true,
    "name.tj": true,
    "name.tr": true,
    "name.tt": true,
    "name.vn": true,
    "namsos.no": true,
    "namsskogan.no": true,
    "nannestad.no": true,
    "naples.it": true,
    "napoli.it": true,
    "nara.jp": true,
    "narod.ru": true,
    "naroy.no": true,
    "narviika.no": true,
    "narvik.no": true,
    "nat.tn": true,
    "national-library-scotland.uk": true,
    "national.museum": true,
    "nationalfirearms.museum": true,
    "nationalheritage.museum": true,
    "nativeamerican.museum": true,
    "naturalhistory.museum": true,
    "naturalhistorymuseum.museum": true,
    "naturalsciences.museum": true,
    "naturbruksgymn.se": true,
    "nature.museum": true,
    "naturhistorisches.museum": true,
    "natuurwetenschappen.museum": true,
    "naumburg.museum": true,
    "naustdal.no": true,
    "naval.museum": true,
    "navigation.aero": true,
    "navuotna.no": true,
    "navy.mil": true,
    "nb.ca": true,
    "nc.us": true,
    "nd.us": true,
    "ne.jp": true,
    "ne.ke": true,
    "ne.kr": true,
    "ne.pw": true,
    "ne.tz": true,
    "ne.ug": true,
    "ne.us": true,
    "nebraska.museum": true,
    "nedre-eiker.no": true,
    "nel.uk": true,
    "neostrada.pl": true,
    "nesna.no": true,
    "nesodden.no": true,
    "nesoddtangen.no": true,
    "nesseby.no": true,
    "nesset.no": true,
    "net.ac": true,
    "net.ae": true,
    "net.af": true,
    "net.ag": true,
    "net.ai": true,
    "net.al": true,
    "net.am": true,
    "net.an": true,
    "net.ar": true,
    "net.au": true,
    "net.az": true,
    "net.ba": true,
    "net.bb": true,
    "net.bd": true,
    "net.bh": true,
    "net.bm": true,
    "net.bn": true,
    "net.bo": true,
    "net.br": true,
    "net.bs": true,
    "net.bt": true,
    "net.bz": true,
    "net.cd": true,
    "net.ch": true,
    "net.ci": true,
    "net.ck": true,
    "net.cm": true,
    "net.cn": true,
    "net.co": true,
    "net.cu": true,
    "net.cy": true,
    "net.dm": true,
    "net.do": true,
    "net.dz": true,
    "net.ec": true,
    "net.eg": true,
    "net.er": true,
    "net.et": true,
    "net.fj": true,
    "net.fk": true,
    "net.ge": true,
    "net.gg": true,
    "net.gn": true,
    "net.gp": true,
    "net.gr": true,
    "net.gt": true,
    "net.gu": true,
    "net.gy": true,
    "net.hk": true,
    "net.hn": true,
    "net.ht": true,
    "net.id": true,
    "net.il": true,
    "net.im": true,
    "net.in": true,
    "net.io": true,
    "net.iq": true,
    "net.ir": true,
    "net.is": true,
    "net.je": true,
    "net.jm": true,
    "net.jo": true,
    "net.jp": true,
    "net.kg": true,
    "net.kh": true,
    "net.ki": true,
    "net.kn": true,
    "net.kw": true,
    "net.ky": true,
    "net.kz": true,
    "net.la": true,
    "net.lb": true,
    "net.lc": true,
    "net.li": true,
    "net.lk": true,
    "net.lr": true,
    "net.lu": true,
    "net.lv": true,
    "net.ly": true,
    "net.ma": true,
    "net.me": true,
    "net.mk": true,
    "net.ml": true,
    "net.mm": true,
    "net.mo": true,
    "net.mp": true,
    "net.ms": true,
    "net.mt": true,
    "net.mu": true,
    "net.mv": true,
    "net.mw": true,
    "net.mx": true,
    "net.my": true,
    "net.na": true,
    "net.nc": true,
    "net.nf": true,
    "net.ng": true,
    "net.ni": true,
    "net.np": true,
    "net.nr": true,
    "net.nz": true,
    "net.om": true,
    "net.pa": true,
    "net.pe": true,
    "net.pg": true,
    "net.ph": true,
    "net.pk": true,
    "net.pl": true,
    "net.pn": true,
    "net.pr": true,
    "net.ps": true,
    "net.pt": true,
    "net.py": true,
    "net.qa": true,
    "net.ru": true,
    "net.rw": true,
    "net.sa": true,
    "net.sb": true,
    "net.sc": true,
    "net.sd": true,
    "net.sg": true,
    "net.sh": true,
    "net.sl": true,
    "net.st": true,
    "net.sy": true,
    "net.tc": true,
    "net.tf": true,
    "net.th": true,
    "net.tj": true,
    "net.tm": true,
    "net.tn": true,
    "net.to": true,
    "net.tr": true,
    "net.tt": true,
    "net.tv": true,
    "net.tw": true,
    "net.ua": true,
    "net.uk": true,
    "net.uy": true,
    "net.uz": true,
    "net.vc": true,
    "net.ve": true,
    "net.vi": true,
    "net.vn": true,
    "net.vu": true,
    "net.ws": true,
    "net.ye": true,
    "net.za": true,
    "net.zm": true,
    "netau.net": true,
    "netfirms.com": true,
    "netsolhost.com": true,
    "neues.museum": true,
    "new.ke": true,
    "newhampshire.museum": true,
    "newjersey.museum": true,
    "newmail.ru": true,
    "newmexico.museum": true,
    "newport.museum": true,
    "news.hu": true,
    "newspaper.museum": true,
    "newyork.museum": true,
    "nextmail.ru": true,
    "nf.ca": true,
    "ngo.lk": true,
    "ngo.ph": true,
    "ngo.pl": true,
    "ngo.za": true,
    "nh.us": true,
    "nhs.uk": true,
    "nic.ar": true,
    "nic.im": true,
    "nic.in": true,
    "nic.tt": true,
    "nic.uk": true,
    "niepce.museum": true,
    "nieruchomosci.pl": true,
    "nightmail.ru": true,
    "niigata.jp": true,
    "nikolaev.ua": true,
    "ning.com": true,
    "nissedal.no": true,
    "nittedal.no": true,
    "nj.us": true,
    "nkz.ru": true,
    "nl.ca": true,
    "nl.no": true,
    "nls.uk": true,
    "nm.cn": true,
    "nm.ru": true,
    "nm.us": true,
    "nnov.ru": true,
    "no-ip.biz": true,
    "no-ip.ca": true,
    "no-ip.com": true,
    "no-ip.info": true,
    "no-ip.net": true,
    "no-ip.org": true,
    "no.com": true,
    "no.it": true,
    "no.tc": true,
    "nom.ad": true,
    "nom.ag": true,
    "nom.br": true,
    "nom.co": true,
    "nom.es": true,
    "nom.fk": true,
    "nom.fr": true,
    "nom.km": true,
    "nom.mg": true,
    "nom.ni": true,
    "nom.pa": true,
    "nom.pe": true,
    "nom.pl": true,
    "nom.re": true,
    "nom.ro": true,
    "nom.sh": true,
    "nom.ve": true,
    "nom.za": true,
    "nome.pt": true,
    "nord-aurdal.no": true,
    "nord-fron.no": true,
    "nord-odal.no": true,
    "norddal.no": true,
    "nordkapp.no": true,
    "nordre-land.no": true,
    "nordreisa.no": true,
    "nore-og-uvdal.no": true,
    "norfolk.museum": true,
    "norilsk.ru": true,
    "north.museum": true,
    "not.br": true,
    "notaires.fr": true,
    "notaires.km": true,
    "notlong.com": true,
    "notodden.no": true,
    "notteroy.no": true,
    "nov.ru": true,
    "novara.it": true,
    "novosibirsk.ru": true,
    "nowaruda.pl": true,
    "nrw.museum": true,
    "ns.ca": true,
    "nsk.ru": true,
    "nsn.us": true,
    "nsw.au": true,
    "nt.au": true,
    "nt.ca": true,
    "nt.no": true,
    "nt.ro": true,
    "ntr.br": true,
    "nu.ca": true,
    "nu.it": true,
    "nuernberg.museum": true,
    "nui.hu": true,
    "nuoro.it": true,
    "nuremberg.museum": true,
    "nv.us": true,
    "nx.cn": true,
    "ny.us": true,
    "nyc.museum": true,
    "nyny.museum": true,
    "nysa.pl": true,
    "o.bg": true,
    "o.se": true,
    "oceanographic.museum": true,
    "oceanographique.museum": true,
    "od.ua": true,
    "odda.no": true,
    "odessa.ua": true,
    "odo.br": true,
    "of.no": true,
    "off.ai": true,
    "og.ao": true,
    "oh.us": true,
    "oita.jp": true,
    "ok.us": true,
    "okayama.jp": true,
    "okinawa.jp": true,
    "oksnes.no": true,
    "ol.no": true,
    "olawa.pl": true,
    "olecko.pl": true,
    "olkusz.pl": true,
    "olsztyn.pl": true,
    "omaha.museum": true,
    "omasvuotna.no": true,
    "omsk.ru": true,
    "on.ca": true,
    "one.pl": true,
    "online.museum": true,
    "ontario.museum": true,
    "openair.museum": true,
    "opoczno.pl": true,
    "opole.pl": true,
    "oppdal.no": true,
    "oppegard.no": true,
    "or.at": true,
    "or.bi": true,
    "or.ci": true,
    "or.cr": true,
    "or.id": true,
    "or.it": true,
    "or.jp": true,
    "or.ke": true,
    "or.kr": true,
    "or.mu": true,
    "or.na": true,
    "or.pw": true,
    "or.th": true,
    "or.tz": true,
    "or.ug": true,
    "or.us": true,
    "oregon.museum": true,
    "oregontrail.museum": true,
    "orenburg.ru": true,
    "org.ac": true,
    "org.ae": true,
    "org.af": true,
    "org.ag": true,
    "org.ai": true,
    "org.al": true,
    "org.am": true,
    "org.an": true,
    "org.ar": true,
    "org.au": true,
    "org.az": true,
    "org.ba": true,
    "org.bb": true,
    "org.bd": true,
    "org.bh": true,
    "org.bi": true,
    "org.bm": true,
    "org.bn": true,
    "org.bo": true,
    "org.br": true,
    "org.bs": true,
    "org.bt": true,
    "org.bw": true,
    "org.bz": true,
    "org.cd": true,
    "org.ch": true,
    "org.ci": true,
    "org.ck": true,
    "org.cn": true,
    "org.co": true,
    "org.cu": true,
    "org.cy": true,
    "org.dm": true,
    "org.do": true,
    "org.dz": true,
    "org.ec": true,
    "org.ee": true,
    "org.eg": true,
    "org.er": true,
    "org.es": true,
    "org.et": true,
    "org.fj": true,
    "org.fk": true,
    "org.ge": true,
    "org.gg": true,
    "org.gh": true,
    "org.gi": true,
    "org.gn": true,
    "org.gp": true,
    "org.gr": true,
    "org.gt": true,
    "org.gu": true,
    "org.hk": true,
    "org.hn": true,
    "org.ht": true,
    "org.hu": true,
    "org.il": true,
    "org.im": true,
    "org.in": true,
    "org.io": true,
    "org.iq": true,
    "org.ir": true,
    "org.is": true,
    "org.je": true,
    "org.jm": true,
    "org.jo": true,
    "org.jp": true,
    "org.kg": true,
    "org.kh": true,
    "org.ki": true,
    "org.km": true,
    "org.kn": true,
    "org.kw": true,
    "org.ky": true,
    "org.kz": true,
    "org.la": true,
    "org.lb": true,
    "org.lc": true,
    "org.li": true,
    "org.lk": true,
    "org.lr": true,
    "org.ls": true,
    "org.lu": true,
    "org.lv": true,
    "org.ly": true,
    "org.ma": true,
    "org.me": true,
    "org.mg": true,
    "org.mk": true,
    "org.ml": true,
    "org.mm": true,
    "org.mn": true,
    "org.mo": true,
    "org.mp": true,
    "org.mt": true,
    "org.mu": true,
    "org.mv": true,
    "org.mw": true,
    "org.mx": true,
    "org.my": true,
    "org.na": true,
    "org.nc": true,
    "org.ng": true,
    "org.ni": true,
    "org.np": true,
    "org.nr": true,
    "org.nz": true,
    "org.om": true,
    "org.pa": true,
    "org.pe": true,
    "org.pf": true,
    "org.ph": true,
    "org.pk": true,
    "org.pl": true,
    "org.pn": true,
    "org.pr": true,
    "org.ps": true,
    "org.pt": true,
    "org.py": true,
    "org.qa": true,
    "org.ro": true,
    "org.rs": true,
    "org.ru": true,
    "org.rw": true,
    "org.sa": true,
    "org.sb": true,
    "org.sc": true,
    "org.sd": true,
    "org.se": true,
    "org.sg": true,
    "org.sh": true,
    "org.sl": true,
    "org.st": true,
    "org.sv": true,
    "org.sy": true,
    "org.sz": true,
    "org.tj": true,
    "org.tm": true,
    "org.tn": true,
    "org.to": true,
    "org.tr": true,
    "org.tt": true,
    "org.tv": true,
    "org.tw": true,
    "org.ua": true,
    "org.uk": true,
    "org.uy": true,
    "org.uz": true,
    "org.vc": true,
    "org.ve": true,
    "org.vi": true,
    "org.vn": true,
    "org.vu": true,
    "org.ws": true,
    "org.ye": true,
    "org.yu": true,
    "org.za": true,
    "org.zm": true,
    "org.zw": true,
    "orge.pl": true,
    "oristano.it": true,
    "orkanger.no": true,
    "orkdal.no": true,
    "orland.no": true,
    "orskog.no": true,
    "orsta.no": true,
    "oryol.ru": true,
    "osa.pl": true,
    "osaka.jp": true,
    "osen.no": true,
    "oskol.ru": true,
    "oslo.no": true,
    "osoyro.no": true,
    "osteroy.no": true,
    "ostre-toten.no": true,
    "ostroda.pl": true,
    "ostroleka.pl": true,
    "ostrowiec.pl": true,
    "ostrowwlkp.pl": true,
    "otago.museum": true,
    "otc.au": true,
    "other.nf": true,
    "overhalla.no": true,
    "ovh.net": true,
    "ovre-eiker.no": true,
    "oxford.museum": true,
    "oyer.no": true,
    "oygarden.no": true,
    "oystre-slidre.no": true,
    "oz.au": true,
    "p.bg": true,
    "p.se": true,
    "pa.it": true,
    "pa.us": true,
    "pacific.museum": true,
    "paderborn.museum": true,
    "padova.it": true,
    "padua.it": true,
    "page.tl": true,
    "palace.museum": true,
    "palana.ru": true,
    "paleo.museum": true,
    "palermo.it": true,
    "palmsprings.museum": true,
    "panama.museum": true,
    "parachuting.aero": true,
    "paragliding.aero": true,
    "paris.museum": true,
    "parliament.cy": true,
    "parliament.uk": true,
    "parma.it": true,
    "parti.se": true,
    "pasadena.museum": true,
    "passenger-association.aero": true,
    "pavia.it": true,
    "pb.ao": true,
    "pc.it": true,
    "pc.pl": true,
    "pd.it": true,
    "pe.ca": true,
    "pe.it": true,
    "pe.kr": true,
    "penza.ru": true,
    "per.kh": true,
    "per.la": true,
    "per.nf": true,
    "per.sg": true,
    "perm.ru": true,
    "perso.ht": true,
    "perso.tc": true,
    "perso.tn": true,
    "perugia.it": true,
    "pesaro-urbino.it": true,
    "pesarourbino.it": true,
    "pescara.it": true,
    "pg.it": true,
    "ph.tc": true,
    "pharmacien.fr": true,
    "pharmaciens.km": true,
    "pharmacy.museum": true,
    "philadelphia.museum": true,
    "philadelphiaarea.museum": true,
    "philately.museum": true,
    "phoenix.museum": true,
    "photography.museum": true,
    "pi.it": true,
    "piacenza.it": true,
    "pila.pl": true,
    "pilot.aero": true,
    "pilots.museum": true,
    "pisa.it": true,
    "pisem.su": true,
    "pistoia.it": true,
    "pisz.pl": true,
    "pittsburgh.museum": true,
    "pl.tc": true,
    "pl.tf": true,
    "pl.ua": true,
    "planetarium.museum": true,
    "plantation.museum": true,
    "plants.museum": true,
    "plaza.museum": true,
    "plc.ly": true,
    "plc.uk": true,
    "plo.ps": true,
    "pn.it": true,
    "po.it": true,
    "pochta.com": true,
    "pochta.ru": true,
    "pochtamt.ru": true,
    "podhale.pl": true,
    "podlasie.pl": true,
    "pol.dz": true,
    "pol.ht": true,
    "pol.tr": true,
    "police.uk": true,
    "polkowice.pl": true,
    "poltava.ua": true,
    "pomorskie.pl": true,
    "pomorze.pl": true,
    "pop3.ru": true,
    "populus.ch": true,
    "pordenone.it": true,
    "porsanger.no": true,
    "porsangu.no": true,
    "porsgrunn.no": true,
    "port.fr": true,
    "portal.museum": true,
    "portland.museum": true,
    "portlligat.museum": true,
    "posts-and-telecommunications.museum": true,
    "potenza.it": true,
    "powiat.pl": true,
    "poznan.pl": true,
    "pp.az": true,
    "pp.ru": true,
    "pp.se": true,
    "pp.ua": true,
    "ppg.br": true,
    "pr.it": true,
    "pr.us": true,
    "prato.it": true,
    "prd.fr": true,
    "prd.km": true,
    "prd.mg": true,
    "preservation.museum": true,
    "presidio.museum": true,
    "press.aero": true,
    "press.cy": true,
    "press.ma": true,
    "press.museum": true,
    "press.se": true,
    "presse.ci": true,
    "presse.fr": true,
    "presse.km": true,
    "pri.ee": true,
    "principe.st": true,
    "priv.at": true,
    "priv.hu": true,
    "priv.me": true,
    "priv.no": true,
    "priv.pl": true,
    "pro.ae": true,
    "pro.az": true,
    "pro.br": true,
    "pro.cy": true,
    "pro.ec": true,
    "pro.fj": true,
    "pro.ht": true,
    "pro.mv": true,
    "pro.na": true,
    "pro.om": true,
    "pro.pr": true,
    "pro.tc": true,
    "pro.tt": true,
    "pro.vn": true,
    "proboards.com": true,
    "prochowice.pl": true,
    "production.aero": true,
    "prof.pr": true,
    "project.museum": true,
    "promocion.ar": true,
    "prserv.net": true,
    "pruszkow.pl": true,
    "przeworsk.pl": true,
    "psc.br": true,
    "psi.br": true,
    "pskov.ru": true,
    "pt.it": true,
    "ptz.ru": true,
    "pu.it": true,
    "pub.sa": true,
    "publ.pt": true,
    "public.museum": true,
    "pubol.museum": true,
    "pulawy.pl": true,
    "pv.it": true,
    "pvt.ge": true,
    "pyatigorsk.ru": true,
    "pz.it": true,
    "q.bg": true,
    "qc.ca": true,
    "qc.com": true,
    "qh.cn": true,
    "qld.au": true,
    "qsl.br": true,
    "quebec.museum": true,
    "r.bg": true,
    "r.se": true,
    "ra.it": true,
    "rade.no": true,
    "radikal.ru": true,
    "radom.pl": true,
    "radoy.no": true,
    "ragusa.it": true,
    "rahkkeravju.no": true,
    "raholt.no": true,
    "railroad.museum": true,
    "railway.museum": true,
    "raisa.no": true,
    "rakkestad.no": true,
    "ralingen.no": true,
    "rana.no": true,
    "randaberg.no": true,
    "rauma.no": true,
    "ravenna.it": true,
    "rawa-maz.pl": true,
    "rbcmail.ru": true,
    "rc.it": true,
    "re.it": true,
    "re.kr": true,
    "realestate.pl": true,
    "rec.br": true,
    "rec.co": true,
    "rec.nf": true,
    "rec.ro": true,
    "rec.ve": true,
    "recreation.aero": true,
    "red.sv": true,
    "redirectme.net": true,
    "reggio-calabria.it": true,
    "reggio-emilia.it": true,
    "reggiocalabria.it": true,
    "reggioemilia.it": true,
    "reklam.hu": true,
    "rel.ht": true,
    "rel.pl": true,
    "rendalen.no": true,
    "rennebu.no": true,
    "rennesoy.no": true,
    "repbody.aero": true,
    "republika.pl": true,
    "res.aero": true,
    "res.in": true,
    "research.aero": true,
    "research.museum": true,
    "resistance.museum": true,
    "retina.ar": true,
    "rg.it": true,
    "ri.it": true,
    "ri.us": true,
    "rieti.it": true,
    "riik.ee": true,
    "rimini.it": true,
    "rindal.no": true,
    "ringebu.no": true,
    "ringerike.no": true,
    "ringsaker.no": true,
    "riodejaneiro.museum": true,
    "risor.no": true,
    "rissa.no": true,
    "rl.no": true,
    "rm.it": true,
    "rm.ru": true,
    "rn.it": true,
    "rnd.ru": true,
    "rnrt.tn": true,
    "rns.tn": true,
    "rnu.tn": true,
    "ro.im": true,
    "ro.it": true,
    "roan.no": true,
    "rochester.museum": true,
    "rockart.museum": true,
    "rodoy.no": true,
    "rollag.no": true,
    "roma.it": true,
    "roma.museum": true,
    "rome.it": true,
    "romsa.no": true,
    "romskog.no": true,
    "roros.no": true,
    "rost.no": true,
    "rotorcraft.aero": true,
    "rovigo.it": true,
    "rovno.ua": true,
    "royken.no": true,
    "royrvik.no": true,
    "rs.ba": true,
    "ru.com": true,
    "ru.tc": true,
    "ru.tf": true,
    "rubtsovsk.ru": true,
    "ruovat.no": true,
    "russia.museum": true,
    "rv.ua": true,
    "ryazan.ru": true,
    "rybnik.pl": true,
    "rygge.no": true,
    "rzeszow.pl": true,
    "s.bg": true,
    "s.se": true,
    "sa.au": true,
    "sa.com": true,
    "sa.cr": true,
    "sa.it": true,
    "safety.aero": true,
    "saga.jp": true,
    "saintlouis.museum": true,
    "saitama.jp": true,
    "sakhalin.ru": true,
    "salangen.no": true,
    "salat.no": true,
    "salem.museum": true,
    "salerno.it": true,
    "saltdal.no": true,
    "salvadordali.museum": true,
    "salzburg.museum": true,
    "samara.ru": true,
    "samnanger.no": true,
    "sandefjord.no": true,
    "sandiego.museum": true,
    "sandnes.no": true,
    "sandnessjoen.no": true,
    "sandoy.no": true,
    "sanfrancisco.museum": true,
    "sanok.pl": true,
    "santabarbara.museum": true,
    "santacruz.museum": true,
    "santafe.museum": true,
    "saotome.st": true,
    "sapo.pt": true,
    "sapporo.jp": true,
    "saratov.ru": true,
    "sark.gg": true,
    "sarpsborg.no": true,
    "saskatchewan.museum": true,
    "sassari.it": true,
    "satx.museum": true,
    "sauda.no": true,
    "sauherad.no": true,
    "savannahga.museum": true,
    "savona.it": true,
    "sc.cn": true,
    "sc.ke": true,
    "sc.kr": true,
    "sc.ug": true,
    "sc.us": true,
    "sch.ae": true,
    "sch.gg": true,
    "sch.id": true,
    "sch.ir": true,
    "sch.je": true,
    "sch.jo": true,
    "sch.lk": true,
    "sch.ly": true,
    "sch.ng": true,
    "sch.om": true,
    "sch.sa": true,
    "sch.sd": true,
    "sch.uk": true,
    "sch.zm": true,
    "schlesisches.museum": true,
    "schoenbrunn.museum": true,
    "schokoladen.museum": true,
    "school.fj": true,
    "school.museum": true,
    "school.na": true,
    "school.nz": true,
    "school.za": true,
    "schweiz.museum": true,
    "sci.eg": true,
    "science-fiction.museum": true,
    "science.museum": true,
    "scienceandhistory.museum": true,
    "scienceandindustry.museum": true,
    "sciencecenter.museum": true,
    "sciencecenters.museum": true,
    "sciencehistory.museum": true,
    "sciences.museum": true,
    "sciencesnaturelles.museum": true,
    "scientist.aero": true,
    "scotland.museum": true,
    "sd.cn": true,
    "sd.us": true,
    "se.com": true,
    "se.net": true,
    "se.tc": true,
    "se.tt": true,
    "seaport.museum": true,
    "sebastopol.ua": true,
    "sec.ps": true,
    "sejny.pl": true,
    "sel.no": true,
    "selbu.no": true,
    "selfip.com": true,
    "selfip.net": true,
    "selje.no": true,
    "seljord.no": true,
    "sendai.jp": true,
    "seoul.kr": true,
    "servebbs.com": true,
    "serveftp.com": true,
    "services.aero": true,
    "settlement.museum": true,
    "settlers.museum": true,
    "sex.hu": true,
    "sex.pl": true,
    "sf.no": true,
    "sg.tf": true,
    "sh.cn": true,
    "sharepoint.com": true,
    "shell.museum": true,
    "sherbrooke.museum": true,
    "shiga.jp": true,
    "shimane.jp": true,
    "shizuoka.jp": true,
    "shop.co": true,
    "shop.ht": true,
    "shop.hu": true,
    "shop.ms": true,
    "shop.pl": true,
    "shop.tc": true,
    "show.aero": true,
    "shutterfly.com": true,
    "si.it": true,
    "sibenik.museum": true,
    "siellak.no": true,
    "siena.it": true,
    "sigdal.no": true,
    "siljan.no": true,
    "silk.museum": true,
    "simbirsk.ru": true,
    "siracusa.it": true,
    "sirdal.no": true,
    "site.tc": true,
    "site90.net": true,
    "sk.ca": true,
    "skanit.no": true,
    "skanland.no": true,
    "skaun.no": true,
    "skedsmo.no": true,
    "skedsmokorset.no": true,
    "ski.museum": true,
    "ski.no": true,
    "skien.no": true,
    "skierva.no": true,
    "skiptvet.no": true,
    "skjak.no": true,
    "skjervoy.no": true,
    "sklep.pl": true,
    "skoczow.pl": true,
    "skodje.no": true,
    "skole.museum": true,
    "skydiving.aero": true,
    "slask.pl": true,
    "slattum.no": true,
    "sld.cu": true,
    "sld.do": true,
    "sld.pa": true,
    "slg.br": true,
    "slupsk.pl": true,
    "smola.no": true,
    "smolensk.ru": true,
    "smtp.ru": true,
    "sn.cn": true,
    "snaase.no": true,
    "snasa.no": true,
    "snillfjord.no": true,
    "snoasa.no": true,
    "snz.ru": true,
    "so.it": true,
    "soc.lk": true,
    "societe.st": true,
    "society.museum": true,
    "software.aero": true,
    "sogndal.no": true,
    "sogne.no": true,
    "sokndal.no": true,
    "sol.ru": true,
    "sola.no": true,
    "sologne.museum": true,
    "solund.no": true,
    "somna.no": true,
    "sondre-land.no": true,
    "sondrio.it": true,
    "songdalen.no": true,
    "sopot.pl": true,
    "sor-aurdal.no": true,
    "sor-fron.no": true,
    "sor-odal.no": true,
    "sor-varanger.no": true,
    "sorfold.no": true,
    "soros.al": true,
    "sorreisa.no": true,
    "sortland.no": true,
    "sorum.no": true,
    "sos.pl": true,
    "sosblog.com": true,
    "sosnowiec.pl": true,
    "soundandvision.museum": true,
    "southcarolina.museum": true,
    "southwest.museum": true,
    "sp.it": true,
    "sp.ru": true,
    "space.museum": true,
    "spb.ru": true,
    "spjelkavik.no": true,
    "sport.hu": true,
    "spy.museum": true,
    "spydeberg.no": true,
    "square.museum": true,
    "sr.it": true,
    "srv.br": true,
    "ss.it": true,
    "sshn.se": true,
    "st.no": true,
    "stadt.museum": true,
    "stalbans.museum": true,
    "stalowa-wola.pl": true,
    "stange.no": true,
    "starachowice.pl": true,
    "stargard.pl": true,
    "starnberg.museum": true,
    "stat.no": true,
    "state.museum": true,
    "stateofdelaware.museum": true,
    "stathelle.no": true,
    "station.museum": true,
    "stavanger.no": true,
    "stavern.no": true,
    "stavropol.ru": true,
    "steam.museum": true,
    "steiermark.museum": true,
    "steigen.no": true,
    "steinkjer.no": true,
    "stjohn.museum": true,
    "stjordal.no": true,
    "stjordalshalsen.no": true,
    "stockholm.museum": true,
    "stokke.no": true,
    "stor-elvdal.no": true,
    "stord.no": true,
    "stordal.no": true,
    "store.co": true,
    "store.nf": true,
    "store.ro": true,
    "store.st": true,
    "store.ve": true,
    "storfjord.no": true,
    "stpetersburg.museum": true,
    "strand.no": true,
    "stranda.no": true,
    "stryn.no": true,
    "student.aero": true,
    "stuttgart.museum": true,
    "stv.ru": true,
    "suedtirol.it": true,
    "suisse.museum": true,
    "sula.no": true,
    "suldal.no": true,
    "suli.hu": true,
    "sumy.ua": true,
    "sund.no": true,
    "sunndal.no": true,
    "surgeonshall.museum": true,
    "surgut.ru": true,
    "surnadal.no": true,
    "surrey.museum": true,
    "suwalki.pl": true,
    "sv.it": true,
    "svalbard.no": true,
    "sveio.no": true,
    "svelvik.no": true,
    "svizzera.museum": true,
    "sweden.museum": true,
    "swidnica.pl": true,
    "swiebodzin.pl": true,
    "swinoujscie.pl": true,
    "sx.cn": true,
    "sydney.museum": true,
    "sykkylven.no": true,
    "syzran.ru": true,
    "szczecin.pl": true,
    "szczytno.pl": true,
    "szex.hu": true,
    "szkola.pl": true,
    "szm.com": true,
    "t.bg": true,
    "t.se": true,
    "t3.to": true,
    "t35.com": true,
    "t35.me": true,
    "t35.net": true,
    "ta.it": true,
    "takamatsu.jp": true,
    "tambov.ru": true,
    "tana.no": true,
    "tananger.no": true,
    "tank.museum": true,
    "taranto.it": true,
    "targi.pl": true,
    "tarnobrzeg.pl": true,
    "tas.au": true,
    "tatarstan.ru": true,
    "taxi.aero": true,
    "tcm.museum": true,
    "te.it": true,
    "te.ua": true,
    "tec.ve": true,
    "technology.museum": true,
    "tel.no": true,
    "tel.nr": true,
    "tel.tr": true,
    "telecom.na": true,
    "telekommunikation.museum": true,
    "telememo.au": true,
    "television.museum": true,
    "teramo.it": true,
    "terni.it": true,
    "ternopil.ua": true,
    "test.ru": true,
    "texas.museum": true,
    "textile.museum": true,
    "tgory.pl": true,
    "th.tc": true,
    "theater.museum": true,
    "time.museum": true,
    "time.no": true,
    "timekeeping.museum": true,
    "tingvoll.no": true,
    "tinn.no": true,
    "tirana.al": true,
    "tj.cn": true,
    "tjeldsund.no": true,
    "tjome.no": true,
    "tld.am": true,
    "tld.tc": true,
    "tld.tl": true,
    "tlf.nr": true,
    "tm.cy": true,
    "tm.fr": true,
    "tm.hu": true,
    "tm.km": true,
    "tm.mc": true,
    "tm.mg": true,
    "tm.mt": true,
    "tm.no": true,
    "tm.pl": true,
    "tm.ro": true,
    "tm.se": true,
    "tm.za": true,
    "tmp.br": true,
    "tn.it": true,
    "tn.us": true,
    "to.it": true,
    "tochigi.jp": true,
    "tokke.no": true,
    "tokushima.jp": true,
    "tokyo.jp": true,
    "tolga.no": true,
    "tom.ru": true,
    "tomsk.ru": true,
    "tonsberg.no": true,
    "topology.museum": true,
    "torino.it": true,
    "torino.museum": true,
    "torsken.no": true,
    "torun.pl": true,
    "tottori.jp": true,
    "touch.museum": true,
    "tourism.pl": true,
    "tourism.tn": true,
    "town.museum": true,
    "toyama.jp": true,
    "tozsde.hu": true,
    "tp.it": true,
    "tr.it": true,
    "tr.no": true,
    "trader.aero": true,
    "trading.aero": true,
    "trainer.aero": true,
    "trana.no": true,
    "tranby.no": true,
    "tranoy.no": true,
    "transport.museum": true,
    "trapani.it": true,
    "travel.pl": true,
    "travel.tt": true,
    "trd.br": true,
    "tree.museum": true,
    "trentino.it": true,
    "trento.it": true,
    "treviso.it": true,
    "trieste.it": true,
    "tripod.com": true,
    "troandin.no": true,
    "trogstad.no": true,
    "trolley.museum": true,
    "tromsa.no": true,
    "tromso.no": true,
    "trondheim.no": true,
    "trust.museum": true,
    "trustee.museum": true,
    "trysil.no": true,
    "ts.it": true,
    "tsaritsyn.ru": true,
    "tsk.ru": true,
    "tula.ru": true,
    "tumblr.com": true,
    "tur.ar": true,
    "tur.br": true,
    "tur.cu": true,
    "turek.pl": true,
    "turen.tn": true,
    "turin.it": true,
    "turystyka.pl": true,
    "tuva.ru": true,
    "tv.bo": true,
    "tv.br": true,
    "tv.it": true,
    "tv.na": true,
    "tv.sd": true,
    "tvedestrand.no": true,
    "tver.ru": true,
    "tw.cn": true,
    "tx.us": true,
    "tychy.pl": true,
    "tydal.no": true,
    "tynset.no": true,
    "tysfjord.no": true,
    "tysnes.no": true,
    "tysvar.no": true,
    "tyumen.ru": true,
    "u.bg": true,
    "u.se": true,
    "ua.tc": true,
    "uba.ar": true,
    "ucoz.ru": true,
    "ud.it": true,
    "udine.it": true,
    "udm.ru": true,
    "udmurtia.ru": true,
    "uhren.museum": true,
    "uk.com": true,
    "uk.mn": true,
    "uk.net": true,
    "uk.pn": true,
    "uk.tc": true,
    "uk.to": true,
    "uk.tt": true,
    "ulan-ude.ru": true,
    "ullensaker.no": true,
    "ullensvang.no": true,
    "ulm.museum": true,
    "ulsan.kr": true,
    "ulvik.no": true,
    "unam.na": true,
    "unbi.ba": true,
    "unblog.fr": true,
    "undersea.museum": true,
    "uni.cc": true,
    "uni.me": true,
    "uni7.net": true,
    "union.aero": true,
    "uniti.al": true,
    "university.museum": true,
    "unjarga.no": true,
    "unlugar.com": true,
    "unsa.ba": true,
    "upt.al": true,
    "uri.arpa": true,
    "url.st": true,
    "urn.arpa": true,
    "us.com": true,
    "us.ms": true,
    "us.na": true,
    "us.org": true,
    "us.tc": true,
    "us.tf": true,
    "us.to": true,
    "us.tt": true,
    "usa.museum": true,
    "usantiques.museum": true,
    "usarts.museum": true,
    "uscountryestate.museum": true,
    "usculture.museum": true,
    "usdecorativearts.museum": true,
    "usenet.pl": true,
    "usgarden.museum": true,
    "ushistory.museum": true,
    "ushuaia.museum": true,
    "uslivinghistory.museum": true,
    "ustka.pl": true,
    "ut.us": true,
    "utah.museum": true,
    "utazas.hu": true,
    "utsira.no": true,
    "utsunomiya.jp": true,
    "uu.mt": true,
    "uvic.museum": true,
    "uy.com": true,
    "uz.ua": true,
    "uzhgorod.ua": true,
    "v.bg": true,
    "va.it": true,
    "va.no": true,
    "va.us": true,
    "vaapste.no": true,
    "vacau.com": true,
    "vadso.no": true,
    "vaga.no": true,
    "vagan.no": true,
    "vagsoy.no": true,
    "vaksdal.no": true,
    "valle.no": true,
    "valley.museum": true,
    "vang.no": true,
    "vantaa.museum": true,
    "vanylven.no": true,
    "vardo.no": true,
    "varese.it": true,
    "varggat.no": true,
    "varoy.no": true,
    "vatican.va": true,
    "vb.it": true,
    "vc.it": true,
    "vdonsk.ru": true,
    "ve.it": true,
    "vefsn.no": true,
    "vega.no": true,
    "vegarshei.no": true,
    "venezia.it": true,
    "venice.it": true,
    "vennesla.no": true,
    "verbania.it": true,
    "vercelli.it": true,
    "verdal.no": true,
    "verona.it": true,
    "verran.no": true,
    "versailles.museum": true,
    "vestby.no": true,
    "vestnes.no": true,
    "vestre-slidre.no": true,
    "vestre-toten.no": true,
    "vestvagoy.no": true,
    "vet.br": true,
    "veterinaire.fr": true,
    "veterinaire.km": true,
    "vevelstad.no": true,
    "vf.no": true,
    "vgs.no": true,
    "vi.it": true,
    "vi.us": true,
    "vibo-valentia.it": true,
    "vibovalentia.it": true,
    "vic.au": true,
    "vicenza.it": true,
    "video.hu": true,
    "vik.no": true,
    "viking.museum": true,
    "vikna.no": true,
    "village.museum": true,
    "vindafjord.no": true,
    "vinnica.ua": true,
    "virginia.museum": true,
    "virtual.museum": true,
    "virtuel.museum": true,
    "viterbo.it": true,
    "vlaanderen.museum": true,
    "vladikavkaz.ru": true,
    "vladimir.ru": true,
    "vladivostok.ru": true,
    "vlog.br": true,
    "vn.ua": true,
    "voagat.no": true,
    "volda.no": true,
    "volgograd.ru": true,
    "volkenkunde.museum": true,
    "vologda.ru": true,
    "voronezh.ru": true,
    "voss.no": true,
    "vossevangen.no": true,
    "vr.it": true,
    "vrn.ru": true,
    "vt.it": true,
    "vt.us": true,
    "vv.cc": true,
    "vv.it": true,
    "vyatka.ru": true,
    "w.bg": true,
    "w.se": true,
    "wa.au": true,
    "wa.us": true,
    "wakayama.jp": true,
    "walbrzych.pl": true,
    "wales.museum": true,
    "wallonie.museum": true,
    "war.museum": true,
    "warmia.pl": true,
    "warszawa.pl": true,
    "washingtondc.museum": true,
    "watch-and-clock.museum": true,
    "watchandclock.museum": true,
    "waw.pl": true,
    "we.bs": true,
    "weather.mobi": true,
    "web-soft.ru": true,
    "web.co": true,
    "web.do": true,
    "web.id": true,
    "web.lk": true,
    "web.nf": true,
    "web.pk": true,
    "web.tj": true,
    "web.tr": true,
    "web.ve": true,
    "web.za": true,
    "webcindario.com": true,
    "webgarden.es": true,
    "webs.com": true,
    "weebly.com": true,
    "wegrow.pl": true,
    "western.museum": true,
    "westfalen.museum": true,
    "whaling.museum": true,
    "whsites.net": true,
    "wi.us": true,
    "wielun.pl": true,
    "wiki.br": true,
    "wildlife.museum": true,
    "williamsburg.museum": true,
    "windmill.museum": true,
    "wlocl.pl": true,
    "wloclawek.pl": true,
    "wodzislaw.pl": true,
    "wolomin.pl": true,
    "wordpress.com": true,
    "workinggroup.aero": true,
    "works.aero": true,
    "workshop.museum": true,
    "wroc.pl": true,
    "wroclaw.pl": true,
    "ws.na": true,
    "wv.us": true,
    "www.ro": true,
    "wy.us": true,
    "wz.cz": true,
    "x.bg": true,
    "x.se": true,
    "xanga.com": true,
    "xf.cz": true,
    "xj.cn": true,
    "xn--aroport-bya.ci": true,
    "xn--drbak-wua.no": true,
    "xn--leagaviika-52b.no": true,
    "xn--ostery-fya.no": true,
    "xn--tysvr-vra.no": true,
    "xn--unjrga-rta.no": true,
    "xn--vegrshei-c0a.no": true,
    "xorg.pl": true,
    "xz.cn": true,
    "y.bg": true,
    "y.se": true,
    "yakutia.ru": true,
    "yamagata.jp": true,
    "yamaguchi.jp": true,
    "yamal.ru": true,
    "yamanashi.jp": true,
    "yaroslavl.ru": true,
    "yekaterinburg.ru": true,
    "yk.ca": true,
    "yn.cn": true,
    "yokohama.jp": true,
    "york.museum": true,
    "yorkshire.museum": true,
    "yosemite.museum": true,
    "youth.museum": true,
    "yuzhno-sakhalinsk.ru": true,
    "z.bg": true,
    "z.se": true,
    "z8.ru": true,
    "za.com": true,
    "za.net": true,
    "za.org": true,
    "za.pl": true,
    "zachpomor.pl": true,
    "zagan.pl": true,
    "zakopane.pl": true,
    "zaporizhzhe.ua": true,
    "zapto.org": true,
    "zarow.pl": true,
    "ze.cx": true,
    "zgora.pl": true,
    "zgorzelec.pl": true,
    "zgrad.ru": true,
    "zhitomir.ua": true,
    "zj.cn": true,
    "zlg.br": true,
    "zmail.ru": true,
    "zone.be": true,
    "zoological.museum": true,
    "zoology.museum": true,
    "zp.ua": true,
    "zt.ua": true
};

/* Given a FQDN, returns only the base domain, and honors two-level TLDs.
 * So for example, www.foo.bar.com returns bar.com, or www.foo.bar.co.uk
 * returns bar.co.uk.
 */
function getBaseDomainFromHost(host) {
    if (host.match(/^[\d.]+$/) != null)
    // IP address.
        return host;

    var parts = host.split(".");
    var level2 = parts.slice(-2).join(".");
    var level3 = parts.slice(-3).join(".");
    if (TLDs[level3])
        return parts.slice(-4).join(".");
    else if (TLDs[level2])
        return level3;
    return level2;
}

function iter() {
    for (let i = 0; i < arguments.length; i++) {
        var arg = arguments[i];
        // duck typing
        if (arg.length !== undefined) {
            for (let idx = 0; idx < arg.length; idx++)
                yield arg[idx];
        } else {
            for (let key in arg)
                yield key
        }
    }
}

function items() {
    for (let i = 0; i < arguments.length; i++) {
        var arg = arguments[i];
        for (var key in arg) {
			let value = arg[key];
            yield [key, value];
        }
    }
}